Class: PureCloud::CallHistoryParticipant

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/call_history_participant.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CallHistoryParticipant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 142

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'id')
    
    
    self.id = attributes[:'id']
    
  
  end

  
  if attributes.has_key?(:'name')
    
    
    self.name = attributes[:'name']
    
  
  end

  
  if attributes.has_key?(:'address')
    
    
    self.address = attributes[:'address']
    
  
  end

  
  if attributes.has_key?(:'startTime')
    
    
    self.start_time = attributes[:'startTime']
    
  
  end

  
  if attributes.has_key?(:'endTime')
    
    
    self.end_time = attributes[:'endTime']
    
  
  end

  
  if attributes.has_key?(:'purpose')
    
    
    self.purpose = attributes[:'purpose']
    
  
  end

  
  if attributes.has_key?(:'direction')
    
    
    self.direction = attributes[:'direction']
    
  
  end

  
  if attributes.has_key?(:'ani')
    
    
    self.ani = attributes[:'ani']
    
  
  end

  
  if attributes.has_key?(:'dnis')
    
    
    self.dnis = attributes[:'dnis']
    
  
  end

  
  if attributes.has_key?(:'user')
    
    
    self.user = attributes[:'user']
    
  
  end

  
  if attributes.has_key?(:'queue')
    
    
    self.queue = attributes[:'queue']
    
  
  end

  
  if attributes.has_key?(:'group')
    
    
    self.group = attributes[:'group']
    
  
  end

  
  if attributes.has_key?(:'disconnectType')
    
    
    self.disconnect_type = attributes[:'disconnectType']
    
  
  end

  
  if attributes.has_key?(:'externalContact')
    
    
    self.external_contact = attributes[:'externalContact']
    
  
  end

  
  if attributes.has_key?(:'externalOrganization')
    
    
    self.external_organization = attributes[:'externalOrganization']
    
  
  end

  
end

Instance Attribute Details

#address ⇒ Object

The participant address.



28
29
30
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 28

def address
  @address
end

#ani ⇒ Object

The call ANI.



43
44
45
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 43

def ani
  @ani
end

#direction ⇒ Object

The participant's direction. Values can be: 'inbound' or 'outbound'



40
41
42
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 40

def direction
  @direction
end

#disconnect_type ⇒ Object

The reason the participant was disconnected from the conversation.



58
59
60
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 58

def disconnect_type
  @disconnect_type
end

#dnis ⇒ Object

The call DNIS.



46
47
48
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 46

def dnis
  @dnis
end

#end_time ⇒ Object

The time when this participant went disconnected for this media (eg: video disconnected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



34
35
36
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 34

def end_time
  @end_time
end

#external_contact ⇒ Object

The PureCloud external contact



61
62
63
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 61

def external_contact
  @external_contact
end

#external_organization ⇒ Object

The PureCloud external organization



64
65
66
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 64

def external_organization
  @external_organization
end

#group ⇒ Object

The group involved in the group ring call.



55
56
57
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 55

def group
  @group
end

#id ⇒ Object

The unique participant ID.



22
23
24
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 22

def id
  @id
end

#name ⇒ Object

The display friendly name of the participant.



25
26
27
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 25

def name
  @name
end

#purpose ⇒ Object

The participant's purpose. Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr



37
38
39
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 37

def purpose
  @purpose
end

#queue ⇒ Object

The PureCloud queue for this participant.



52
53
54
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 52

def queue
  @queue
end

#start_time ⇒ Object

The time when this participant first joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



31
32
33
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 31

def start_time
  @start_time
end

#user ⇒ Object

The PureCloud user for this participant.



49
50
51
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 49

def user
  @user
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 67

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'address' => :'address',
    
    :'start_time' => :'startTime',
    
    :'end_time' => :'endTime',
    
    :'purpose' => :'purpose',
    
    :'direction' => :'direction',
    
    :'ani' => :'ani',
    
    :'dnis' => :'dnis',
    
    :'user' => :'user',
    
    :'queue' => :'queue',
    
    :'group' => :'group',
    
    :'disconnect_type' => :'disconnectType',
    
    :'external_contact' => :'externalContact',
    
    :'external_organization' => :'externalOrganization'
    
  }
end

.swagger_types ⇒ Object

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 104

def self.swagger_types
  {
    
    :'id' => :'String',
    
    :'name' => :'String',
    
    :'address' => :'String',
    
    :'start_time' => :'DateTime',
    
    :'end_time' => :'DateTime',
    
    :'purpose' => :'String',
    
    :'direction' => :'String',
    
    :'ani' => :'String',
    
    :'dnis' => :'String',
    
    :'user' => :'UriReference',
    
    :'queue' => :'UriReference',
    
    :'group' => :'UriReference',
    
    :'disconnect_type' => :'String',
    
    :'external_contact' => :'UriReference',
    
    :'external_organization' => :'UriReference'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 467

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      address == o.address &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      purpose == o.purpose &&
      direction == o.direction &&
      ani == o.ani &&
      dnis == o.dnis &&
      user == o.user &&
      queue == o.queue &&
      group == o.group &&
      disconnect_type == o.disconnect_type &&
      external_contact == o.external_contact &&
      external_organization == o.external_organization
end

#_deserialize(type, value) ⇒ Object



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 519

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 579

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 500

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


489
490
491
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 489

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



495
496
497
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 495

def hash
  [id, name, address, start_time, end_time, purpose, direction, ani, dnis, user, queue, group, disconnect_type, external_contact, external_organization].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



288
289
290
291
292
293
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 288

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_body ⇒ Object

to_body is an alias to to_body (backward compatibility))



562
563
564
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 562

def to_body
  to_hash
end

#to_hash ⇒ Object

return the object in the form of hash



567
568
569
570
571
572
573
574
575
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 567

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ Object



557
558
559
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 557

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/purecloudplatformclientv2/models/call_history_participant.rb', line 297

def valid?
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["inbound", "outbound"]
  if @direction && !allowed_values.include?(@direction)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["endpoint", "client", "system", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
  if @disconnect_type && !allowed_values.include?(@disconnect_type)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
end