Class: PureCloud::Coretype
- Inherits:
-
Object
- Object
- PureCloud::Coretype
- Defined in:
- lib/purecloudplatformclientv2/models/coretype.rb
Instance Attribute Summary collapse
-
#current ⇒ Object
A boolean indicating if the core type’s version is the current one in use by the system.
-
#date_created ⇒ Object
The date the core type was created.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#item_validation_fields ⇒ Object
Specific to the "tag" core type, this is an array of strings naming the tag item fields of the core type subject to validation.
-
#item_validation_limits ⇒ Object
A structure denoting the system-imposed minimum and maximum string length for string-array based core types such as "tag" and "enum".
-
#name ⇒ Object
Returns the value of attribute name.
-
#schema ⇒ Object
The core type’s built-in schema.
-
#self_uri ⇒ Object
The URI for this object.
-
#validation_fields ⇒ Object
An array of strings naming the fields of the core type subject to validation.
-
#validation_limits ⇒ Object
A structure denoting the system-imposed minimum and maximum string length (for text-based core types) or numeric values (for number-based) core types.
-
#version ⇒ Object
A positive integer denoting the core type’s version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Coretype
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Coretype
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 113 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'version') self.version = attributes[:'version'] end if attributes.has_key?(:'dateCreated') self.date_created = attributes[:'dateCreated'] end if attributes.has_key?(:'schema') self.schema = attributes[:'schema'] end if attributes.has_key?(:'current') self.current = attributes[:'current'] end if attributes.has_key?(:'validationFields') if (value = attributes[:'validationFields']).is_a?(Array) self.validation_fields = value end end if attributes.has_key?(:'validationLimits') self.validation_limits = attributes[:'validationLimits'] end if attributes.has_key?(:'itemValidationFields') if (value = attributes[:'itemValidationFields']).is_a?(Array) self.item_validation_fields = value end end if attributes.has_key?(:'itemValidationLimits') self.item_validation_limits = attributes[:'itemValidationLimits'] end if attributes.has_key?(:'selfUri') self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#current ⇒ Object
A boolean indicating if the core type’s version is the current one in use by the system
36 37 38 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 36 def current @current end |
#date_created ⇒ Object
The date the core type was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
30 31 32 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 30 def date_created @date_created end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 22 def id @id end |
#item_validation_fields ⇒ Object
Specific to the "tag" core type, this is an array of strings naming the tag item fields of the core type subject to validation
45 46 47 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 45 def item_validation_fields @item_validation_fields end |
#item_validation_limits ⇒ Object
A structure denoting the system-imposed minimum and maximum string length for string-array based core types such as "tag" and "enum". Forexample, the validationLimits for a schema field using a tag core type specify the min/max values for a minimum string length (minLength) constraint supplied by a schema author on individual tags. Similarly, the maxLength’s min/max specifies maximum string length constraint supplied by a schema author for the same field’s tags.
48 49 50 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 48 def item_validation_limits @item_validation_limits end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 24 def name @name end |
#schema ⇒ Object
The core type’s built-in schema
33 34 35 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 33 def schema @schema end |
#self_uri ⇒ Object
The URI for this object
51 52 53 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 51 def self_uri @self_uri end |
#validation_fields ⇒ Object
An array of strings naming the fields of the core type subject to validation. Validation constraints are specified by a schema author using the core type.
39 40 41 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 39 def validation_fields @validation_fields end |
#validation_limits ⇒ Object
A structure denoting the system-imposed minimum and maximum string length (for text-based core types) or numeric values (for number-based) core types. For example, the validationLimits for a text-based core type specify the min/max values for a minimum string length (minLength) constraint supplied by a schemaauthor on a text field. Similarly, the maxLength’s min/max specifies maximum string length constraint supplied by a schema author for the same field.
42 43 44 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 42 def validation_limits @validation_limits end |
#version ⇒ Object
A positive integer denoting the core type’s version
27 28 29 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 27 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 54 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'version' => :'version', :'date_created' => :'dateCreated', :'schema' => :'schema', :'current' => :'current', :'validation_fields' => :'validationFields', :'validation_limits' => :'validationLimits', :'item_validation_fields' => :'itemValidationFields', :'item_validation_limits' => :'itemValidationLimits', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 83 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'version' => :'Integer', :'date_created' => :'DateTime', :'schema' => :'Schema', :'current' => :'BOOLEAN', :'validation_fields' => :'Array<String>', :'validation_limits' => :'ValidationLimits', :'item_validation_fields' => :'Array<String>', :'item_validation_limits' => :'ItemValidationLimits', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 342 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && version == o.version && date_created == o.date_created && schema == o.schema && current == o.current && validation_fields == o.validation_fields && validation_limits == o.validation_limits && item_validation_fields == o.item_validation_fields && item_validation_limits == o.item_validation_limits && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 390 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 450 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 371 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
360 361 362 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 360 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
366 367 368 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 366 def hash [id, name, version, date_created, schema, current, validation_fields, validation_limits, item_validation_fields, item_validation_limits, self_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
227 228 229 230 231 232 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 227 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
433 434 435 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 433 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
438 439 440 441 442 443 444 445 446 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 438 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
428 429 430 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 428 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/purecloudplatformclientv2/models/coretype.rb', line 236 def valid? end |