Class: PureCloud::CreateEmailRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/create_email_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateEmailRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 128

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'queueId')
    
    
    self.queue_id = attributes[:'queueId']
    
  
  end

  
  if attributes.has_key?(:'flowId')
    
    
    self.flow_id = attributes[:'flowId']
    
  
  end

  
  if attributes.has_key?(:'provider')
    
    
    self.provider = attributes[:'provider']
    
  
  end

  
  if attributes.has_key?(:'skillIds')
    
    if (value = attributes[:'skillIds']).is_a?(Array)
      self.skill_ids = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'languageId')
    
    
    self.language_id = attributes[:'languageId']
    
  
  end

  
  if attributes.has_key?(:'priority')
    
    
    self.priority = attributes[:'priority']
    
  
  end

  
  if attributes.has_key?(:'attributes')
    
    if (value = attributes[:'attributes']).is_a?(Array)
      self.attributes = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'toAddress')
    
    
    self.to_address = attributes[:'toAddress']
    
  
  end

  
  if attributes.has_key?(:'toName')
    
    
    self.to_name = attributes[:'toName']
    
  
  end

  
  if attributes.has_key?(:'fromAddress')
    
    
    self.from_address = attributes[:'fromAddress']
    
  
  end

  
  if attributes.has_key?(:'fromName')
    
    
    self.from_name = attributes[:'fromName']
    
  
  end

  
  if attributes.has_key?(:'subject')
    
    
    self.subject = attributes[:'subject']
    
  
  end

  
  if attributes.has_key?(:'direction')
    
    
    self.direction = attributes[:'direction']
    
  
  end

  
end

Instance Attribute Details

#attributesObject

The list of attributes to associate with the customer participant.



40
41
42
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 40

def attributes
  @attributes
end

#directionObject

Specify INBOUND to create an inbound email conversation to route to a queue, or OUTBOUND to send an email on behalf of a queue.



58
59
60
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 58

def direction
  @direction
end

#flow_idObject

The ID of the flow to use for routing chat conversation. This field is mutually exclusive with queueId



25
26
27
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 25

def flow_id
  @flow_id
end

#from_addressObject

The email address of the sender of the email.



49
50
51
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 49

def from_address
  @from_address
end

#from_nameObject

The name of the sender of the email.



52
53
54
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 52

def from_name
  @from_name
end

#language_idObject

The ID of the language to use for routing.



34
35
36
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 34

def language_id
  @language_id
end

#priorityObject

The priority to assign to the conversation for routing.



37
38
39
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 37

def priority
  @priority
end

#providerObject

The name of the provider that is sourcing the web chat.



28
29
30
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 28

def provider
  @provider
end

#queue_idObject

The ID of the queue to use for routing the chat conversation. This field is mutually exclusive with flowId



22
23
24
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 22

def queue_id
  @queue_id
end

#skill_idsObject

The list of skill ID’s to use for routing.



31
32
33
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 31

def skill_ids
  @skill_ids
end

#subjectObject

The subject of the email



55
56
57
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 55

def subject
  @subject
end

#to_addressObject

The email address of the recipient of the email.



43
44
45
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 43

def to_address
  @to_address
end

#to_nameObject

The name of the recipient of the email.



46
47
48
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 46

def to_name
  @to_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 61

def self.attribute_map
  {
    
    :'queue_id' => :'queueId',
    
    :'flow_id' => :'flowId',
    
    :'provider' => :'provider',
    
    :'skill_ids' => :'skillIds',
    
    :'language_id' => :'languageId',
    
    :'priority' => :'priority',
    
    :'attributes' => :'attributes',
    
    :'to_address' => :'toAddress',
    
    :'to_name' => :'toName',
    
    :'from_address' => :'fromAddress',
    
    :'from_name' => :'fromName',
    
    :'subject' => :'subject',
    
    :'direction' => :'direction'
    
  }
end

.swagger_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 94

def self.swagger_types
  {
    
    :'queue_id' => :'String',
    
    :'flow_id' => :'String',
    
    :'provider' => :'String',
    
    :'skill_ids' => :'Array<String>',
    
    :'language_id' => :'String',
    
    :'priority' => :'Integer',
    
    :'attributes' => :'Hash<String, String>',
    
    :'to_address' => :'String',
    
    :'to_name' => :'String',
    
    :'from_address' => :'String',
    
    :'from_name' => :'String',
    
    :'subject' => :'String',
    
    :'direction' => :'String'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 412

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      queue_id == o.queue_id &&
      flow_id == o.flow_id &&
      provider == o.provider &&
      skill_ids == o.skill_ids &&
      language_id == o.language_id &&
      priority == o.priority &&
      attributes == o.attributes &&
      to_address == o.to_address &&
      to_name == o.to_name &&
      from_address == o.from_address &&
      from_name == o.from_name &&
      subject == o.subject &&
      direction == o.direction
end

#_deserialize(type, value) ⇒ Object



462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 462

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 522

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 443

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


432
433
434
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 432

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



438
439
440
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 438

def hash
  [queue_id, flow_id, provider, skill_ids, language_id, priority, attributes, to_address, to_name, from_address, from_name, subject, direction].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



260
261
262
263
264
265
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 260

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



505
506
507
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 505

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



510
511
512
513
514
515
516
517
518
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 510

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



500
501
502
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 500

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/purecloudplatformclientv2/models/create_email_request.rb', line 269

def valid?
  
  
  
  
  
  
  
  
  
  
  if @provider.nil?
    return false
  end

  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["OUTBOUND", "INBOUND"]
  if @direction && !allowed_values.include?(@direction)
    return false
  end
  
  
  
end