Class: PureCloud::DomainLogicalInterface
- Inherits:
-
Object
- Object
- PureCloud::DomainLogicalInterface
- Defined in:
- lib/purecloudplatformclientv2/models/domain_logical_interface.rb
Instance Attribute Summary collapse
-
#addresses ⇒ Object
The list of IP addresses on this interface.
-
#command_responses ⇒ Object
Returns the value of attribute command_responses.
-
#created_by ⇒ Object
The ID of the user that created the resource.
-
#created_by_app ⇒ Object
The application that created the resource.
-
#current_state ⇒ Object
Returns the value of attribute current_state.
-
#date_created ⇒ Object
The date the resource was created.
-
#date_modified ⇒ Object
The date of the last modification to the resource.
-
#description ⇒ Object
The resource’s description.
-
#edge_assigned_id ⇒ Object
Returns the value of attribute edge_assigned_id.
-
#edge_uri ⇒ Object
Returns the value of attribute edge_uri.
-
#end_date ⇒ Object
Date time is represented as an ISO-8601 string.
-
#external_trunk_base_assignments ⇒ Object
External trunk base settings to use for external communication from this interface.
-
#friendly_name ⇒ Object
Friendly Name.
-
#hardware_address ⇒ Object
Hardware Address.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#if_status ⇒ Object
Returns the value of attribute if_status.
-
#inherit_phone_trunk_bases_i_pv4 ⇒ Object
The IPv4 phone trunk base assignment will be inherited from the Edge Group.
-
#inherit_phone_trunk_bases_i_pv6 ⇒ Object
The IPv6 phone trunk base assignment will be inherited from the Edge Group.
-
#interface_type ⇒ Object
The type of this network interface.
-
#ipv4_capabilities ⇒ Object
IPv4 interface settings.
-
#ipv6_capabilities ⇒ Object
IPv6 interface settings.
-
#last_modified_correlation_id ⇒ Object
Returns the value of attribute last_modified_correlation_id.
-
#last_modified_user_id ⇒ Object
Returns the value of attribute last_modified_user_id.
-
#modified_by ⇒ Object
The ID of the user that last modified the resource.
-
#modified_by_app ⇒ Object
The application that last modified the resource.
-
#name ⇒ Object
The name of the entity.
-
#phone_trunk_base_assignments ⇒ Object
Phone trunk base settings to use for phone communication from this interface.
-
#physical_adapter_id ⇒ Object
Physical Adapter Id.
-
#routes ⇒ Object
The list of routes assigned to this interface.
-
#self_uri ⇒ Object
The URI for this object.
-
#start_date ⇒ Object
Date time is represented as an ISO-8601 string.
-
#state ⇒ Object
Indicates if the resource is active, inactive, or deleted.
-
#trace_enabled ⇒ Object
Returns the value of attribute trace_enabled.
-
#use_for_internal_edge_communication ⇒ Object
This interface will be used for all internal edge-to-edge communication using settings from the edgeTrunkBaseAssignment on the Edge Group.
-
#version ⇒ Object
The current version of the resource.
-
#vlan_tag_id ⇒ Object
Returns the value of attribute vlan_tag_id.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainLogicalInterface
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DomainLogicalInterface
Initializes the object
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 280 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'version') self.version = attributes[:'version'] end if attributes.has_key?(:'dateCreated') self.date_created = attributes[:'dateCreated'] end if attributes.has_key?(:'dateModified') self.date_modified = attributes[:'dateModified'] end if attributes.has_key?(:'modifiedBy') self.modified_by = attributes[:'modifiedBy'] end if attributes.has_key?(:'createdBy') self.created_by = attributes[:'createdBy'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'modifiedByApp') self.modified_by_app = attributes[:'modifiedByApp'] end if attributes.has_key?(:'createdByApp') self.created_by_app = attributes[:'createdByApp'] end if attributes.has_key?(:'edgeUri') self.edge_uri = attributes[:'edgeUri'] end if attributes.has_key?(:'edgeAssignedId') self.edge_assigned_id = attributes[:'edgeAssignedId'] end if attributes.has_key?(:'friendlyName') self.friendly_name = attributes[:'friendlyName'] end if attributes.has_key?(:'vlanTagId') self.vlan_tag_id = attributes[:'vlanTagId'] end if attributes.has_key?(:'hardwareAddress') self.hardware_address = attributes[:'hardwareAddress'] end if attributes.has_key?(:'physicalAdapterId') self.physical_adapter_id = attributes[:'physicalAdapterId'] end if attributes.has_key?(:'ifStatus') self.if_status = attributes[:'ifStatus'] end if attributes.has_key?(:'interfaceType') self.interface_type = attributes[:'interfaceType'] end if attributes.has_key?(:'routes') if (value = attributes[:'routes']).is_a?(Array) self.routes = value end end if attributes.has_key?(:'addresses') if (value = attributes[:'addresses']).is_a?(Array) self.addresses = value end end if attributes.has_key?(:'ipv4Capabilities') self.ipv4_capabilities = attributes[:'ipv4Capabilities'] end if attributes.has_key?(:'ipv6Capabilities') self.ipv6_capabilities = attributes[:'ipv6Capabilities'] end if attributes.has_key?(:'currentState') self.current_state = attributes[:'currentState'] end if attributes.has_key?(:'lastModifiedUserId') self.last_modified_user_id = attributes[:'lastModifiedUserId'] end if attributes.has_key?(:'lastModifiedCorrelationId') self.last_modified_correlation_id = attributes[:'lastModifiedCorrelationId'] end if attributes.has_key?(:'commandResponses') if (value = attributes[:'commandResponses']).is_a?(Array) self.command_responses = value end end if attributes.has_key?(:'inheritPhoneTrunkBasesIPv4') self.inherit_phone_trunk_bases_i_pv4 = attributes[:'inheritPhoneTrunkBasesIPv4'] end if attributes.has_key?(:'inheritPhoneTrunkBasesIPv6') self.inherit_phone_trunk_bases_i_pv6 = attributes[:'inheritPhoneTrunkBasesIPv6'] end if attributes.has_key?(:'useForInternalEdgeCommunication') self.use_for_internal_edge_communication = attributes[:'useForInternalEdgeCommunication'] end if attributes.has_key?(:'externalTrunkBaseAssignments') if (value = attributes[:'externalTrunkBaseAssignments']).is_a?(Array) self.external_trunk_base_assignments = value end end if attributes.has_key?(:'phoneTrunkBaseAssignments') if (value = attributes[:'phoneTrunkBaseAssignments']).is_a?(Array) self.phone_trunk_base_assignments = value end end if attributes.has_key?(:'traceEnabled') self.trace_enabled = attributes[:'traceEnabled'] end if attributes.has_key?(:'startDate') self.start_date = attributes[:'startDate'] end if attributes.has_key?(:'endDate') self.end_date = attributes[:'endDate'] end if attributes.has_key?(:'selfUri') self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#addresses ⇒ Object
The list of IP addresses on this interface. Priority of dns addresses are based on order in the list.
78 79 80 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 78 def addresses @addresses end |
#command_responses ⇒ Object
Returns the value of attribute command_responses.
92 93 94 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 92 def command_responses @command_responses end |
#created_by ⇒ Object
The ID of the user that created the resource.
43 44 45 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 43 def created_by @created_by end |
#created_by_app ⇒ Object
The application that created the resource.
52 53 54 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 52 def created_by_app @created_by_app end |
#current_state ⇒ Object
Returns the value of attribute current_state.
86 87 88 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 86 def current_state @current_state end |
#date_created ⇒ Object
The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
34 35 36 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 34 def date_created @date_created end |
#date_modified ⇒ Object
The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
37 38 39 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 37 def date_modified @date_modified end |
#description ⇒ Object
The resource’s description.
28 29 30 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 28 def description @description end |
#edge_assigned_id ⇒ Object
Returns the value of attribute edge_assigned_id.
56 57 58 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 56 def edge_assigned_id @edge_assigned_id end |
#edge_uri ⇒ Object
Returns the value of attribute edge_uri.
54 55 56 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 54 def edge_uri @edge_uri end |
#end_date ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
115 116 117 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 115 def end_date @end_date end |
#external_trunk_base_assignments ⇒ Object
External trunk base settings to use for external communication from this interface.
104 105 106 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 104 def external_trunk_base_assignments @external_trunk_base_assignments end |
#friendly_name ⇒ Object
Friendly Name
59 60 61 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 59 def friendly_name @friendly_name end |
#hardware_address ⇒ Object
Hardware Address
64 65 66 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 64 def hardware_address @hardware_address end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 22 def id @id end |
#if_status ⇒ Object
Returns the value of attribute if_status.
69 70 71 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 69 def if_status @if_status end |
#inherit_phone_trunk_bases_i_pv4 ⇒ Object
The IPv4 phone trunk base assignment will be inherited from the Edge Group.
95 96 97 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 95 def inherit_phone_trunk_bases_i_pv4 @inherit_phone_trunk_bases_i_pv4 end |
#inherit_phone_trunk_bases_i_pv6 ⇒ Object
The IPv6 phone trunk base assignment will be inherited from the Edge Group.
98 99 100 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 98 def inherit_phone_trunk_bases_i_pv6 @inherit_phone_trunk_bases_i_pv6 end |
#interface_type ⇒ Object
The type of this network interface.
72 73 74 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 72 def interface_type @interface_type end |
#ipv4_capabilities ⇒ Object
IPv4 interface settings.
81 82 83 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 81 def ipv4_capabilities @ipv4_capabilities end |
#ipv6_capabilities ⇒ Object
IPv6 interface settings.
84 85 86 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 84 def ipv6_capabilities @ipv6_capabilities end |
#last_modified_correlation_id ⇒ Object
Returns the value of attribute last_modified_correlation_id.
90 91 92 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 90 def last_modified_correlation_id @last_modified_correlation_id end |
#last_modified_user_id ⇒ Object
Returns the value of attribute last_modified_user_id.
88 89 90 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 88 def last_modified_user_id @last_modified_user_id end |
#modified_by ⇒ Object
The ID of the user that last modified the resource.
40 41 42 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 40 def modified_by @modified_by end |
#modified_by_app ⇒ Object
The application that last modified the resource.
49 50 51 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 49 def modified_by_app @modified_by_app end |
#name ⇒ Object
The name of the entity.
25 26 27 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 25 def name @name end |
#phone_trunk_base_assignments ⇒ Object
Phone trunk base settings to use for phone communication from this interface. These settings will be ignored when "inheritPhoneTrunkBases" is true.
107 108 109 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 107 def phone_trunk_base_assignments @phone_trunk_base_assignments end |
#physical_adapter_id ⇒ Object
Physical Adapter Id
67 68 69 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 67 def physical_adapter_id @physical_adapter_id end |
#routes ⇒ Object
The list of routes assigned to this interface.
75 76 77 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 75 def routes @routes end |
#self_uri ⇒ Object
The URI for this object
118 119 120 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 118 def self_uri @self_uri end |
#start_date ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
112 113 114 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 112 def start_date @start_date end |
#state ⇒ Object
Indicates if the resource is active, inactive, or deleted.
46 47 48 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 46 def state @state end |
#trace_enabled ⇒ Object
Returns the value of attribute trace_enabled.
109 110 111 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 109 def trace_enabled @trace_enabled end |
#use_for_internal_edge_communication ⇒ Object
This interface will be used for all internal edge-to-edge communication using settings from the edgeTrunkBaseAssignment on the Edge Group.
101 102 103 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 101 def use_for_internal_edge_communication @use_for_internal_edge_communication end |
#version ⇒ Object
The current version of the resource.
31 32 33 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 31 def version @version end |
#vlan_tag_id ⇒ Object
Returns the value of attribute vlan_tag_id.
61 62 63 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 61 def vlan_tag_id @vlan_tag_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 121 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'version' => :'version', :'date_created' => :'dateCreated', :'date_modified' => :'dateModified', :'modified_by' => :'modifiedBy', :'created_by' => :'createdBy', :'state' => :'state', :'modified_by_app' => :'modifiedByApp', :'created_by_app' => :'createdByApp', :'edge_uri' => :'edgeUri', :'edge_assigned_id' => :'edgeAssignedId', :'friendly_name' => :'friendlyName', :'vlan_tag_id' => :'vlanTagId', :'hardware_address' => :'hardwareAddress', :'physical_adapter_id' => :'physicalAdapterId', :'if_status' => :'ifStatus', :'interface_type' => :'interfaceType', :'routes' => :'routes', :'addresses' => :'addresses', :'ipv4_capabilities' => :'ipv4Capabilities', :'ipv6_capabilities' => :'ipv6Capabilities', :'current_state' => :'currentState', :'last_modified_user_id' => :'lastModifiedUserId', :'last_modified_correlation_id' => :'lastModifiedCorrelationId', :'command_responses' => :'commandResponses', :'inherit_phone_trunk_bases_i_pv4' => :'inheritPhoneTrunkBasesIPv4', :'inherit_phone_trunk_bases_i_pv6' => :'inheritPhoneTrunkBasesIPv6', :'use_for_internal_edge_communication' => :'useForInternalEdgeCommunication', :'external_trunk_base_assignments' => :'externalTrunkBaseAssignments', :'phone_trunk_base_assignments' => :'phoneTrunkBaseAssignments', :'trace_enabled' => :'traceEnabled', :'start_date' => :'startDate', :'end_date' => :'endDate', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 200 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'version' => :'Integer', :'date_created' => :'DateTime', :'date_modified' => :'DateTime', :'modified_by' => :'String', :'created_by' => :'String', :'state' => :'String', :'modified_by_app' => :'String', :'created_by_app' => :'String', :'edge_uri' => :'String', :'edge_assigned_id' => :'String', :'friendly_name' => :'String', :'vlan_tag_id' => :'Integer', :'hardware_address' => :'String', :'physical_adapter_id' => :'String', :'if_status' => :'String', :'interface_type' => :'String', :'routes' => :'Array<DomainNetworkRoute>', :'addresses' => :'Array<DomainNetworkAddress>', :'ipv4_capabilities' => :'DomainCapabilities', :'ipv6_capabilities' => :'DomainCapabilities', :'current_state' => :'String', :'last_modified_user_id' => :'String', :'last_modified_correlation_id' => :'String', :'command_responses' => :'Array<DomainNetworkCommandResponse>', :'inherit_phone_trunk_bases_i_pv4' => :'BOOLEAN', :'inherit_phone_trunk_bases_i_pv6' => :'BOOLEAN', :'use_for_internal_edge_communication' => :'BOOLEAN', :'external_trunk_base_assignments' => :'Array<TrunkBaseAssignment>', :'phone_trunk_base_assignments' => :'Array<TrunkBaseAssignment>', :'trace_enabled' => :'BOOLEAN', :'start_date' => :'DateTime', :'end_date' => :'DateTime', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1027 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && version == o.version && date_created == o.date_created && date_modified == o.date_modified && modified_by == o.modified_by && created_by == o.created_by && state == o.state && modified_by_app == o.modified_by_app && created_by_app == o.created_by_app && edge_uri == o.edge_uri && edge_assigned_id == o.edge_assigned_id && friendly_name == o.friendly_name && vlan_tag_id == o.vlan_tag_id && hardware_address == o.hardware_address && physical_adapter_id == o.physical_adapter_id && if_status == o.if_status && interface_type == o.interface_type && routes == o.routes && addresses == o.addresses && ipv4_capabilities == o.ipv4_capabilities && ipv6_capabilities == o.ipv6_capabilities && current_state == o.current_state && last_modified_user_id == o.last_modified_user_id && last_modified_correlation_id == o.last_modified_correlation_id && command_responses == o.command_responses && inherit_phone_trunk_bases_i_pv4 == o.inherit_phone_trunk_bases_i_pv4 && inherit_phone_trunk_bases_i_pv6 == o.inherit_phone_trunk_bases_i_pv6 && use_for_internal_edge_communication == o.use_for_internal_edge_communication && external_trunk_base_assignments == o.external_trunk_base_assignments && phone_trunk_base_assignments == o.phone_trunk_base_assignments && trace_enabled == o.trace_enabled && start_date == o.start_date && end_date == o.end_date && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1100 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1160 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1081 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
1070 1071 1072 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1070 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
1076 1077 1078 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1076 def hash [id, name, description, version, date_created, date_modified, modified_by, created_by, state, modified_by_app, created_by_app, edge_uri, edge_assigned_id, friendly_name, vlan_tag_id, hardware_address, physical_adapter_id, if_status, interface_type, routes, addresses, ipv4_capabilities, ipv6_capabilities, current_state, last_modified_user_id, last_modified_correlation_id, command_responses, inherit_phone_trunk_bases_i_pv4, inherit_phone_trunk_bases_i_pv6, use_for_internal_edge_communication, external_trunk_base_assignments, phone_trunk_base_assignments, trace_enabled, start_date, end_date, self_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
625 626 627 628 629 630 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 625 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
1143 1144 1145 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1143 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
1138 1139 1140 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 1138 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 |
# File 'lib/purecloudplatformclientv2/models/domain_logical_interface.rb', line 634 def valid? if @name.nil? return false end allowed_values = ["active", "inactive", "deleted"] if @state && !allowed_values.include?(@state) return false end if @friendly_name.nil? return false end if @hardware_address.nil? return false end if @physical_adapter_id.nil? return false end allowed_values = ["DIAGNOSTIC", "SYSTEM"] if @interface_type && !allowed_values.include?(@interface_type) return false end allowed_values = ["INIT", "CREATING", "UPDATING", "OK", "EXCEPTION", "DELETING"] if @current_state && !allowed_values.include?(@current_state) return false end end |