Class: PureCloud::Edge

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/edge.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Edge

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 200

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.has_key?(:'dateCreated')
    self.date_created = attributes[:'dateCreated']
  end

  if attributes.has_key?(:'dateModified')
    self.date_modified = attributes[:'dateModified']
  end

  if attributes.has_key?(:'modifiedBy')
    self.modified_by = attributes[:'modifiedBy']
  end

  if attributes.has_key?(:'createdBy')
    self.created_by = attributes[:'createdBy']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'modifiedByApp')
    self.modified_by_app = attributes[:'modifiedByApp']
  end

  if attributes.has_key?(:'createdByApp')
    self.created_by_app = attributes[:'createdByApp']
  end

  if attributes.has_key?(:'interfaces')
    if (value = attributes[:'interfaces']).is_a?(Array)
      self.interfaces = value
    end
  end

  if attributes.has_key?(:'make')
    self.make = attributes[:'make']
  end

  if attributes.has_key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.has_key?(:'apiVersion')
    self.api_version = attributes[:'apiVersion']
  end

  if attributes.has_key?(:'softwareVersion')
    self.software_version = attributes[:'softwareVersion']
  end

  if attributes.has_key?(:'softwareVersionTimestamp')
    self.software_version_timestamp = attributes[:'softwareVersionTimestamp']
  end

  if attributes.has_key?(:'softwareVersionPlatform')
    self.software_version_platform = attributes[:'softwareVersionPlatform']
  end

  if attributes.has_key?(:'softwareVersionConfiguration')
    self.software_version_configuration = attributes[:'softwareVersionConfiguration']
  end

  if attributes.has_key?(:'fullSoftwareVersion')
    self.full_software_version = attributes[:'fullSoftwareVersion']
  end

  if attributes.has_key?(:'pairingId')
    self.pairing_id = attributes[:'pairingId']
  end

  if attributes.has_key?(:'fingerprint')
    self.fingerprint = attributes[:'fingerprint']
  end

  if attributes.has_key?(:'fingerprintHint')
    self.fingerprint_hint = attributes[:'fingerprintHint']
  end

  if attributes.has_key?(:'currentVersion')
    self.current_version = attributes[:'currentVersion']
  end

  if attributes.has_key?(:'stagedVersion')
    self.staged_version = attributes[:'stagedVersion']
  end

  if attributes.has_key?(:'patch')
    self.patch = attributes[:'patch']
  end

  if attributes.has_key?(:'statusCode')
    self.status_code = attributes[:'statusCode']
  end

  if attributes.has_key?(:'edgeGroup')
    self.edge_group = attributes[:'edgeGroup']
  end

  if attributes.has_key?(:'site')
    self.site = attributes[:'site']
  end

  if attributes.has_key?(:'softwareStatus')
    self.software_status = attributes[:'softwareStatus']
  end

  if attributes.has_key?(:'onlineStatus')
    self.online_status = attributes[:'onlineStatus']
  end

  if attributes.has_key?(:'serialNumber')
    self.serial_number = attributes[:'serialNumber']
  end

  if attributes.has_key?(:'physicalEdge')
    self.physical_edge = attributes[:'physicalEdge']
  end

  if attributes.has_key?(:'managed')
    self.managed = attributes[:'managed']
  end

  if attributes.has_key?(:'edgeDeploymentType')
    self.edge_deployment_type = attributes[:'edgeDeploymentType']
  end

  if attributes.has_key?(:'callDrainingState')
    self.call_draining_state = attributes[:'callDrainingState']
  end

  if attributes.has_key?(:'conversationCount')
    self.conversation_count = attributes[:'conversationCount']
  end

  if attributes.has_key?(:'proxy')
    self.proxy = attributes[:'proxy']
  end

  if attributes.has_key?(:'selfUri')
    self.self_uri = attributes[:'selfUri']
  end

end

Instance Attribute Details

#api_versionObject

Returns the value of attribute api_version.



54
55
56
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 54

def api_version
  @api_version
end

#call_draining_stateObject

Returns the value of attribute call_draining_state.



98
99
100
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 98

def call_draining_state
  @call_draining_state
end

#conversation_countObject

Returns the value of attribute conversation_count.



100
101
102
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 100

def conversation_count
  @conversation_count
end

#created_byObject

Returns the value of attribute created_by.



39
40
41
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 39

def created_by
  @created_by
end

#created_by_appObject

Returns the value of attribute created_by_app.



45
46
47
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 45

def created_by_app
  @created_by_app
end

#current_versionObject

Returns the value of attribute current_version.



73
74
75
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 73

def current_version
  @current_version
end

#date_createdObject

Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



32
33
34
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 32

def date_created
  @date_created
end

#date_modifiedObject

Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



35
36
37
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 35

def date_modified
  @date_modified
end

#descriptionObject

Returns the value of attribute description.



27
28
29
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 27

def description
  @description
end

#edge_deployment_typeObject

Returns the value of attribute edge_deployment_type.



96
97
98
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 96

def edge_deployment_type
  @edge_deployment_type
end

#edge_groupObject

Returns the value of attribute edge_group.



81
82
83
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 81

def edge_group
  @edge_group
end

#fingerprintObject

Returns the value of attribute fingerprint.



69
70
71
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 69

def fingerprint
  @fingerprint
end

#fingerprint_hintObject

Returns the value of attribute fingerprint_hint.



71
72
73
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 71

def fingerprint_hint
  @fingerprint_hint
end

#full_software_versionObject

Returns the value of attribute full_software_version.



64
65
66
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 64

def full_software_version
  @full_software_version
end

#idObject

The globally unique identifier for the object.



22
23
24
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 22

def id
  @id
end

#interfacesObject

The list of interfaces for the edge. (Deprecated) Replaced by configuring trunks/ip info on the logical interface instead



48
49
50
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 48

def interfaces
  @interfaces
end

#makeObject

Returns the value of attribute make.



50
51
52
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 50

def make
  @make
end

#managedObject

Returns the value of attribute managed.



94
95
96
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 94

def managed
  @managed
end

#modelObject

Returns the value of attribute model.



52
53
54
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 52

def model
  @model
end

#modified_byObject

Returns the value of attribute modified_by.



37
38
39
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 37

def modified_by
  @modified_by
end

#modified_by_appObject

Returns the value of attribute modified_by_app.



43
44
45
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 43

def modified_by_app
  @modified_by_app
end

#nameObject

The name of the entity.



25
26
27
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 25

def name
  @name
end

#online_statusObject

Returns the value of attribute online_status.



88
89
90
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 88

def online_status
  @online_status
end

#pairing_idObject

The pairing Id for a hardware Edge in the format: 00000-00000-00000-00000-00000. This field is only required when creating an Edge with a deployment type of HARDWARE.



67
68
69
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 67

def pairing_id
  @pairing_id
end

#patchObject

Returns the value of attribute patch.



77
78
79
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 77

def patch
  @patch
end

#physical_edgeObject

Returns the value of attribute physical_edge.



92
93
94
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 92

def physical_edge
  @physical_edge
end

#proxyObject

Edge HTTP proxy configuration for the WAN port. The field can be a hostname, FQDN, IPv4 or IPv6 address. If port is not included, port 80 is assumed.



103
104
105
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 103

def proxy
  @proxy
end

#self_uriObject

The URI for this object



106
107
108
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 106

def self_uri
  @self_uri
end

#serial_numberObject

Returns the value of attribute serial_number.



90
91
92
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 90

def serial_number
  @serial_number
end

#siteObject

The Site to which the Edge is assigned.



84
85
86
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 84

def site
  @site
end

#software_statusObject

Returns the value of attribute software_status.



86
87
88
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 86

def software_status
  @software_status
end

#software_versionObject

Returns the value of attribute software_version.



56
57
58
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 56

def software_version
  @software_version
end

#software_version_configurationObject

Returns the value of attribute software_version_configuration.



62
63
64
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 62

def software_version_configuration
  @software_version_configuration
end

#software_version_platformObject

Returns the value of attribute software_version_platform.



60
61
62
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 60

def software_version_platform
  @software_version_platform
end

#software_version_timestampObject

Returns the value of attribute software_version_timestamp.



58
59
60
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 58

def software_version_timestamp
  @software_version_timestamp
end

#staged_versionObject

Returns the value of attribute staged_version.



75
76
77
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 75

def staged_version
  @staged_version
end

#stateObject

Returns the value of attribute state.



41
42
43
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 41

def state
  @state
end

#status_codeObject

Returns the value of attribute status_code.



79
80
81
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 79

def status_code
  @status_code
end

#versionObject

Returns the value of attribute version.



29
30
31
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 29

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 109

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'version' => :'version',
    :'date_created' => :'dateCreated',
    :'date_modified' => :'dateModified',
    :'modified_by' => :'modifiedBy',
    :'created_by' => :'createdBy',
    :'state' => :'state',
    :'modified_by_app' => :'modifiedByApp',
    :'created_by_app' => :'createdByApp',
    :'interfaces' => :'interfaces',
    :'make' => :'make',
    :'model' => :'model',
    :'api_version' => :'apiVersion',
    :'software_version' => :'softwareVersion',
    :'software_version_timestamp' => :'softwareVersionTimestamp',
    :'software_version_platform' => :'softwareVersionPlatform',
    :'software_version_configuration' => :'softwareVersionConfiguration',
    :'full_software_version' => :'fullSoftwareVersion',
    :'pairing_id' => :'pairingId',
    :'fingerprint' => :'fingerprint',
    :'fingerprint_hint' => :'fingerprintHint',
    :'current_version' => :'currentVersion',
    :'staged_version' => :'stagedVersion',
    :'patch' => :'patch',
    :'status_code' => :'statusCode',
    :'edge_group' => :'edgeGroup',
    :'site' => :'site',
    :'software_status' => :'softwareStatus',
    :'online_status' => :'onlineStatus',
    :'serial_number' => :'serialNumber',
    :'physical_edge' => :'physicalEdge',
    :'managed' => :'managed',
    :'edge_deployment_type' => :'edgeDeploymentType',
    :'call_draining_state' => :'callDrainingState',
    :'conversation_count' => :'conversationCount',
    :'proxy' => :'proxy',
    :'self_uri' => :'selfUri'
  }
end

.swagger_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 154

def self.swagger_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'version' => :'Integer',
    :'date_created' => :'DateTime',
    :'date_modified' => :'DateTime',
    :'modified_by' => :'String',
    :'created_by' => :'String',
    :'state' => :'String',
    :'modified_by_app' => :'String',
    :'created_by_app' => :'String',
    :'interfaces' => :'Array<EdgeInterface>',
    :'make' => :'String',
    :'model' => :'String',
    :'api_version' => :'String',
    :'software_version' => :'String',
    :'software_version_timestamp' => :'String',
    :'software_version_platform' => :'String',
    :'software_version_configuration' => :'String',
    :'full_software_version' => :'String',
    :'pairing_id' => :'String',
    :'fingerprint' => :'String',
    :'fingerprint_hint' => :'String',
    :'current_version' => :'String',
    :'staged_version' => :'String',
    :'patch' => :'String',
    :'status_code' => :'String',
    :'edge_group' => :'EdgeGroup',
    :'site' => :'Site',
    :'software_status' => :'DomainEdgeSoftwareUpdateDto',
    :'online_status' => :'String',
    :'serial_number' => :'String',
    :'physical_edge' => :'BOOLEAN',
    :'managed' => :'BOOLEAN',
    :'edge_deployment_type' => :'String',
    :'call_draining_state' => :'String',
    :'conversation_count' => :'Integer',
    :'proxy' => :'String',
    :'self_uri' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 454

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      version == o.version &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      modified_by == o.modified_by &&
      created_by == o.created_by &&
      state == o.state &&
      modified_by_app == o.modified_by_app &&
      created_by_app == o.created_by_app &&
      interfaces == o.interfaces &&
      make == o.make &&
      model == o.model &&
      api_version == o.api_version &&
      software_version == o.software_version &&
      software_version_timestamp == o.software_version_timestamp &&
      software_version_platform == o.software_version_platform &&
      software_version_configuration == o.software_version_configuration &&
      full_software_version == o.full_software_version &&
      pairing_id == o.pairing_id &&
      fingerprint == o.fingerprint &&
      fingerprint_hint == o.fingerprint_hint &&
      current_version == o.current_version &&
      staged_version == o.staged_version &&
      patch == o.patch &&
      status_code == o.status_code &&
      edge_group == o.edge_group &&
      site == o.site &&
      software_status == o.software_status &&
      online_status == o.online_status &&
      serial_number == o.serial_number &&
      physical_edge == o.physical_edge &&
      managed == o.managed &&
      edge_deployment_type == o.edge_deployment_type &&
      call_draining_state == o.call_draining_state &&
      conversation_count == o.conversation_count &&
      proxy == o.proxy &&
      self_uri == o.self_uri
end

#_deserialize(type, value) ⇒ Object



530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 530

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 590

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 511

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


500
501
502
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 500

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



506
507
508
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 506

def hash
  [id, name, description, version, date_created, date_modified, modified_by, created_by, state, modified_by_app, created_by_app, interfaces, make, model, api_version, software_version, software_version_timestamp, software_version_platform, software_version_configuration, full_software_version, pairing_id, fingerprint, fingerprint_hint, current_version, staged_version, patch, status_code, edge_group, site, software_status, online_status, serial_number, physical_edge, managed, edge_deployment_type, call_draining_state, conversation_count, proxy, self_uri].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



368
369
370
371
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 368

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



573
574
575
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 573

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



578
579
580
581
582
583
584
585
586
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 578

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



568
569
570
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 568

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/purecloudplatformclientv2/models/edge.rb', line 375

def valid?
  if @name.nil?
    return false
  end

  allowed_values = ["active", "inactive", "deleted"]
  if @state && !allowed_values.include?(@state)
    return false
  end
  allowed_values = ["NEW", "AWAITING_CONNECTION", "AWAITING_FINGERPRINT", "AWAITING_FINGERPRINT_VERIFICATION", "FINGERPRINT_VERIFIED", "AWAITING_BOOTSTRAP", "ACTIVE", "INACTIVE", "RMA", "UNPAIRING", "UNPAIRED"]
  if @status_code && !allowed_values.include?(@status_code)
    return false
  end
  allowed_values = ["ONLINE", "OFFLINE"]
  if @online_status && !allowed_values.include?(@online_status)
    return false
  end
  allowed_values = ["HARDWARE", "LDM", "CDM", "INVALID"]
  if @edge_deployment_type && !allowed_values.include?(@edge_deployment_type)
    return false
  end
  allowed_values = ["NONE", "WAIT", "WAIT_TIMEOUT", "TERMINATE", "COMPLETE"]
  if @call_draining_state && !allowed_values.include?(@call_draining_state)
    return false
  end
end