Class: PureCloud::EncryptionKey
- Inherits:
-
Object
- Object
- PureCloud::EncryptionKey
- Defined in:
- lib/purecloudplatformclientv2/models/encryption_key.rb
Instance Attribute Summary collapse
-
#create_date ⇒ Object
create date of the key pair.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#keydata_summary ⇒ Object
key data summary (base 64 encoded public key).
-
#local_encryption_configuration ⇒ Object
Local configuration.
-
#name ⇒ Object
Returns the value of attribute name.
-
#self_uri ⇒ Object
The URI for this object.
-
#user ⇒ Object
user that requested generation of public key.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EncryptionKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EncryptionKey
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'createDate') self.create_date = attributes[:'createDate'] end if attributes.has_key?(:'keydataSummary') self.keydata_summary = attributes[:'keydataSummary'] end if attributes.has_key?(:'user') self.user = attributes[:'user'] end if attributes.has_key?(:'localEncryptionConfiguration') self.local_encryption_configuration = attributes[:'localEncryptionConfiguration'] end if attributes.has_key?(:'selfUri') self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#create_date ⇒ Object
create date of the key pair. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
27 28 29 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 27 def create_date @create_date end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 22 def id @id end |
#keydata_summary ⇒ Object
key data summary (base 64 encoded public key)
30 31 32 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 30 def keydata_summary @keydata_summary end |
#local_encryption_configuration ⇒ Object
Local configuration
36 37 38 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 36 def local_encryption_configuration @local_encryption_configuration end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 24 def name @name end |
#self_uri ⇒ Object
The URI for this object
39 40 41 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 39 def self_uri @self_uri end |
#user ⇒ Object
user that requested generation of public key
33 34 35 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 33 def user @user end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 42 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'create_date' => :'createDate', :'keydata_summary' => :'keydataSummary', :'user' => :'user', :'local_encryption_configuration' => :'localEncryptionConfiguration', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 55 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'create_date' => :'DateTime', :'keydata_summary' => :'String', :'user' => :'User', :'local_encryption_configuration' => :'LocalEncryptionConfiguration', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 119 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && create_date == o.create_date && keydata_summary == o.keydata_summary && user == o.user && local_encryption_configuration == o.local_encryption_configuration && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 163 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 223 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 144 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
133 134 135 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 133 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 139 def hash [id, name, create_date, keydata_summary, user, local_encryption_configuration, self_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 107 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
206 207 208 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 206 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
211 212 213 214 215 216 217 218 219 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
201 202 203 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 201 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 |
# File 'lib/purecloudplatformclientv2/models/encryption_key.rb', line 114 def valid? end |