Class: PureCloud::EventMessage

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/event_message.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EventMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 59

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.has_key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.has_key?(:'messageWithParams')
    self.message_with_params = attributes[:'messageWithParams']
  end

  if attributes.has_key?(:'messageParams')
    if (value = attributes[:'messageParams']).is_a?(Array)
      self.message_params = value
    end
  end

  if attributes.has_key?(:'documentationUri')
    self.documentation_uri = attributes[:'documentationUri']
  end

  if attributes.has_key?(:'resourceURIs')
    if (value = attributes[:'resourceURIs']).is_a?(Array)
      self.resource_ur_is = value
    end
  end

end

Instance Attribute Details

#codeObject

Returns the value of attribute code.



21
22
23
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 21

def code
  @code
end

#documentation_uriObject

Returns the value of attribute documentation_uri.



29
30
31
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 29

def documentation_uri
  @documentation_uri
end

#messageObject

Returns the value of attribute message.



23
24
25
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 23

def message
  @message
end

#message_paramsObject

Returns the value of attribute message_params.



27
28
29
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 27

def message_params
  @message_params
end

#message_with_paramsObject

Returns the value of attribute message_with_params.



25
26
27
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 25

def message_with_params
  @message_with_params
end

#resource_ur_isObject

Returns the value of attribute resource_ur_is.



31
32
33
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 31

def resource_ur_is
  @resource_ur_is
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 34

def self.attribute_map
  {
    :'code' => :'code',
    :'message' => :'message',
    :'message_with_params' => :'messageWithParams',
    :'message_params' => :'messageParams',
    :'documentation_uri' => :'documentationUri',
    :'resource_ur_is' => :'resourceURIs'
  }
end

.swagger_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
55
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 46

def self.swagger_types
  {
    :'code' => :'String',
    :'message' => :'String',
    :'message_with_params' => :'String',
    :'message_params' => :'Hash<String, Object>',
    :'documentation_uri' => :'String',
    :'resource_ur_is' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



123
124
125
126
127
128
129
130
131
132
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 123

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
      message == o.message &&
      message_with_params == o.message_with_params &&
      message_params == o.message_params &&
      documentation_uri == o.documentation_uri &&
      resource_ur_is == o.resource_ur_is
end

#_deserialize(type, value) ⇒ Object



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 166

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 226

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 147

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


136
137
138
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 136

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



142
143
144
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 142

def hash
  [code, message, message_with_params, message_params, documentation_uri, resource_ur_is].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



97
98
99
100
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 97

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



209
210
211
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 209

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



214
215
216
217
218
219
220
221
222
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



204
205
206
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 204

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



104
105
106
107
108
109
# File 'lib/purecloudplatformclientv2/models/event_message.rb', line 104

def valid?
  allowed_values = ["CAMPAIGN_START_ERROR", "CAMPAIGN_RULE_START_ERROR", "CAMPAIGN_SET_DIALING_MODE_ERROR", "INVALID_CALLABLE_TIME_ZONE", "CALLBACK_CREATION_INVALID_NUMBER", "CALL_RULE_INVALID_CONTACT_COLUMN", "CALL_RULE_MISMATCH_TYPE", "CALL_RULE_INVALID_OPERATOR", "CALL_RULE_NO_DNC_LISTS_CONFIGURED", "CONTACT_LIST_FILTER_EVALUATION_FAILED", "INVALID_PHONE_NUMBER", "IMPORT_FAILED_TO_READ_HEADERS", "IMPORT_COULD_NOT_PARSE_AN_ENTRY", "IMPORT_CONTACT_DOES_NOT_MATCH_LIST_FORMAT", "IMPORT_ENTRY_DOES_NOT_ALIGN_WITH_HEADERS", "IMPORT_INVALID_CUSTOM_ID", "IMPORT_INVALID_DATA", "IMPORT_NO_COLUMNS_DEFINED", "IMPORT_COLUMNS_DO_NOT_EXIST_ON_LIST", "IMPORT_LIST_NO_LONGER_EXISTS", "RECYCLE_CAMPAIGN"]
  if @code && !allowed_values.include?(@code)
    return false
  end
end