Class: PureCloud::FlowNotificationNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/flow_notification_notification.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FlowNotificationNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'deleted')
    self.deleted = attributes[:'deleted']
  end

  if attributes.has_key?(:'checkedInVersion')
    self.checked_in_version = attributes[:'checkedInVersion']
  end

  if attributes.has_key?(:'savedVersion')
    self.saved_version = attributes[:'savedVersion']
  end

  if attributes.has_key?(:'publishedVersion')
    self.published_version = attributes[:'publishedVersion']
  end

  if attributes.has_key?(:'currentOperation')
    self.current_operation = attributes[:'currentOperation']
  end

end

Instance Attribute Details

#checked_in_versionObject

Returns the value of attribute checked_in_version.



29
30
31
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 29

def checked_in_version
  @checked_in_version
end

#current_operationObject

Returns the value of attribute current_operation.



35
36
37
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 35

def current_operation
  @current_operation
end

#deletedObject

Returns the value of attribute deleted.



27
28
29
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 27

def deleted
  @deleted
end

#descriptionObject

Returns the value of attribute description.



25
26
27
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 25

def description
  @description
end

#idObject

Returns the value of attribute id.



21
22
23
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 21

def id
  @id
end

#nameObject

Returns the value of attribute name.



23
24
25
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 23

def name
  @name
end

#published_versionObject

Returns the value of attribute published_version.



33
34
35
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 33

def published_version
  @published_version
end

#saved_versionObject

Returns the value of attribute saved_version.



31
32
33
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 31

def saved_version
  @saved_version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'deleted' => :'deleted',
    :'checked_in_version' => :'checkedInVersion',
    :'saved_version' => :'savedVersion',
    :'published_version' => :'publishedVersion',
    :'current_operation' => :'currentOperation'
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 52

def self.swagger_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'deleted' => :'BOOLEAN',
    :'checked_in_version' => :'DocumentDataV2NotificationWorkspace',
    :'saved_version' => :'FlowNotificationNotificationFlowVersion',
    :'published_version' => :'FlowNotificationNotificationFlowVersion',
    :'current_operation' => :'PromptNotificationNotificationCurrentOperation'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 121

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      deleted == o.deleted &&
      checked_in_version == o.checked_in_version &&
      saved_version == o.saved_version &&
      published_version == o.published_version &&
      current_operation == o.current_operation
end

#_deserialize(type, value) ⇒ Object



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 166

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 226

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 147

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


136
137
138
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 136

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



142
143
144
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 142

def hash
  [id, name, description, deleted, checked_in_version, saved_version, published_version, current_operation].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



109
110
111
112
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 109

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



209
210
211
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 209

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



214
215
216
217
218
219
220
221
222
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



204
205
206
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 204

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
# File 'lib/purecloudplatformclientv2/models/flow_notification_notification.rb', line 116

def valid?
end