Class: PureCloud::IVR
- Inherits:
-
Object
- Object
- PureCloud::IVR
- Defined in:
- lib/purecloudplatformclientv2/models/ivr.rb
Overview
Defines the phone numbers, operating hours, and the Architect flows to execute for an IVR.
Instance Attribute Summary collapse
-
#closed_hours_flow ⇒ Object
The Architect flow to execute during the hours an organization is closed.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_by_app ⇒ Object
Returns the value of attribute created_by_app.
-
#date_created ⇒ Object
Date time is represented as an ISO-8601 string.
-
#date_modified ⇒ Object
Date time is represented as an ISO-8601 string.
-
#description ⇒ Object
Returns the value of attribute description.
-
#dnis ⇒ Object
The phone number(s) to contact the IVR by.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#modified_by ⇒ Object
Returns the value of attribute modified_by.
-
#modified_by_app ⇒ Object
Returns the value of attribute modified_by_app.
-
#name ⇒ Object
The name of the entity.
-
#open_hours_flow ⇒ Object
The Architect flow to execute during the hours an organization is open.
-
#schedule_group ⇒ Object
The schedule group defining the open and closed hours for an organization.
-
#self_uri ⇒ Object
The URI for this object.
-
#state ⇒ Object
Returns the value of attribute state.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IVR
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IVR
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 143 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'version') self.version = attributes[:'version'] end if attributes.has_key?(:'dateCreated') self.date_created = attributes[:'dateCreated'] end if attributes.has_key?(:'dateModified') self.date_modified = attributes[:'dateModified'] end if attributes.has_key?(:'modifiedBy') self.modified_by = attributes[:'modifiedBy'] end if attributes.has_key?(:'createdBy') self.created_by = attributes[:'createdBy'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'modifiedByApp') self.modified_by_app = attributes[:'modifiedByApp'] end if attributes.has_key?(:'createdByApp') self.created_by_app = attributes[:'createdByApp'] end if attributes.has_key?(:'dnis') if (value = attributes[:'dnis']).is_a?(Array) self.dnis = value end end if attributes.has_key?(:'openHoursFlow') self.open_hours_flow = attributes[:'openHoursFlow'] end if attributes.has_key?(:'closedHoursFlow') self.closed_hours_flow = attributes[:'closedHoursFlow'] end if attributes.has_key?(:'scheduleGroup') self.schedule_group = attributes[:'scheduleGroup'] end if attributes.has_key?(:'selfUri') self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#closed_hours_flow ⇒ Object
The Architect flow to execute during the hours an organization is closed.
55 56 57 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 55 def closed_hours_flow @closed_hours_flow end |
#created_by ⇒ Object
Returns the value of attribute created_by.
40 41 42 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 40 def created_by @created_by end |
#created_by_app ⇒ Object
Returns the value of attribute created_by_app.
46 47 48 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 46 def created_by_app @created_by_app end |
#date_created ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
33 34 35 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 33 def date_created @date_created end |
#date_modified ⇒ Object
Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
36 37 38 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 36 def date_modified @date_modified end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 28 def description @description end |
#dnis ⇒ Object
The phone number(s) to contact the IVR by. Each phone number must be unique and not in use by another resource. For example, a user and an iVR cannot have the same phone number.
49 50 51 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 49 def dnis @dnis end |
#id ⇒ Object
The globally unique identifier for the object.
23 24 25 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 23 def id @id end |
#modified_by ⇒ Object
Returns the value of attribute modified_by.
38 39 40 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 38 def modified_by @modified_by end |
#modified_by_app ⇒ Object
Returns the value of attribute modified_by_app.
44 45 46 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 44 def modified_by_app @modified_by_app end |
#name ⇒ Object
The name of the entity.
26 27 28 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 26 def name @name end |
#open_hours_flow ⇒ Object
The Architect flow to execute during the hours an organization is open.
52 53 54 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 52 def open_hours_flow @open_hours_flow end |
#schedule_group ⇒ Object
The schedule group defining the open and closed hours for an organization. If this is provided, an open flow and a closed flow must be specified as well.
58 59 60 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 58 def schedule_group @schedule_group end |
#self_uri ⇒ Object
The URI for this object
61 62 63 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 61 def self_uri @self_uri end |
#state ⇒ Object
Returns the value of attribute state.
42 43 44 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 42 def state @state end |
#version ⇒ Object
Returns the value of attribute version.
30 31 32 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 30 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 64 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'version' => :'version', :'date_created' => :'dateCreated', :'date_modified' => :'dateModified', :'modified_by' => :'modifiedBy', :'created_by' => :'createdBy', :'state' => :'state', :'modified_by_app' => :'modifiedByApp', :'created_by_app' => :'createdByApp', :'dnis' => :'dnis', :'open_hours_flow' => :'openHoursFlow', :'closed_hours_flow' => :'closedHoursFlow', :'schedule_group' => :'scheduleGroup', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 103 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'version' => :'Integer', :'date_created' => :'DateTime', :'date_modified' => :'DateTime', :'modified_by' => :'String', :'created_by' => :'String', :'state' => :'String', :'modified_by_app' => :'String', :'created_by_app' => :'String', :'dnis' => :'Array<String>', :'open_hours_flow' => :'UriReference', :'closed_hours_flow' => :'UriReference', :'schedule_group' => :'UriReference', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 479 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && version == o.version && date_created == o.date_created && date_modified == o.date_modified && modified_by == o.modified_by && created_by == o.created_by && state == o.state && modified_by_app == o.modified_by_app && created_by_app == o.created_by_app && dnis == o.dnis && open_hours_flow == o.open_hours_flow && closed_hours_flow == o.closed_hours_flow && schedule_group == o.schedule_group && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 532 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 592 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 513 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
502 503 504 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 502 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
508 509 510 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 508 def hash [id, name, description, version, date_created, date_modified, modified_by, created_by, state, modified_by_app, created_by_app, dnis, open_hours_flow, closed_hours_flow, schedule_group, self_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
300 301 302 303 304 305 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 300 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
575 576 577 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 575 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
580 581 582 583 584 585 586 587 588 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 580 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
570 571 572 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 570 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/purecloudplatformclientv2/models/ivr.rb', line 309 def valid? if @name.nil? return false end allowed_values = ["active", "inactive", "deleted"] if @state && !allowed_values.include?(@state) return false end end |