Class: PureCloud::LocationCreateUpdateDefinition

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/location_create_update_definition.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LocationCreateUpdateDefinition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 94

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'name')
    
    
    self.name = attributes[:'name']
    
  
  end

  
  if attributes.has_key?(:'address')
    
    
    self.address = attributes[:'address']
    
  
  end

  
  if attributes.has_key?(:'emergencyNumber')
    
    
    self.emergency_number = attributes[:'emergencyNumber']
    
  
  end

  
  if attributes.has_key?(:'version')
    
    
    self.version = attributes[:'version']
    
  
  end

  
  if attributes.has_key?(:'state')
    
    
    self.state = attributes[:'state']
    
  
  end

  
  if attributes.has_key?(:'notes')
    
    
    self.notes = attributes[:'notes']
    
  
  end

  
  if attributes.has_key?(:'contactUser')
    
    
    self.contact_user = attributes[:'contactUser']
    
  
  end

  
  if attributes.has_key?(:'path')
    
    if (value = attributes[:'path']).is_a?(Array)
      self.path = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'addressVerified')
    
    
    self.address_verified = attributes[:'addressVerified']
    
  
  end

  
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



24
25
26
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 24

def address
  @address
end

#address_verifiedObject

Returns the value of attribute address_verified.



40
41
42
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 40

def address_verified
  @address_verified
end

#contact_userObject

The user id of the location contact



36
37
38
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 36

def contact_user
  @contact_user
end

#emergency_numberObject

Returns the value of attribute emergency_number.



26
27
28
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 26

def emergency_number
  @emergency_number
end

#nameObject

The name of the Location.



22
23
24
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 22

def name
  @name
end

#notesObject

Returns the value of attribute notes.



33
34
35
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 33

def notes
  @notes
end

#pathObject

Returns the value of attribute path.



38
39
40
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 38

def path
  @path
end

#stateObject

Current activity status of the location.



31
32
33
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 31

def state
  @state
end

#versionObject

Returns the value of attribute version.



28
29
30
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 28

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 43

def self.attribute_map
  {
    
    :'name' => :'name',
    
    :'address' => :'address',
    
    :'emergency_number' => :'emergencyNumber',
    
    :'version' => :'version',
    
    :'state' => :'state',
    
    :'notes' => :'notes',
    
    :'contact_user' => :'contactUser',
    
    :'path' => :'path',
    
    :'address_verified' => :'addressVerified'
    
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 68

def self.swagger_types
  {
    
    :'name' => :'String',
    
    :'address' => :'LocationAddress',
    
    :'emergency_number' => :'LocationEmergencyNumber',
    
    :'version' => :'Integer',
    
    :'state' => :'String',
    
    :'notes' => :'String',
    
    :'contact_user' => :'String',
    
    :'path' => :'Array<String>',
    
    :'address_verified' => :'BOOLEAN'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      address == o.address &&
      emergency_number == o.emergency_number &&
      version == o.version &&
      state == o.state &&
      notes == o.notes &&
      contact_user == o.contact_user &&
      path == o.path &&
      address_verified == o.address_verified
end

#_deserialize(type, value) ⇒ Object



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 350

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 410

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 331

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 320

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



326
327
328
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 326

def hash
  [name, address, emergency_number, version, state, notes, contact_user, path, address_verified].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



188
189
190
191
192
193
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 188

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



393
394
395
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 393

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



398
399
400
401
402
403
404
405
406
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 398

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



388
389
390
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 388

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/purecloudplatformclientv2/models/location_create_update_definition.rb', line 197

def valid?
  
  
  if @name.nil?
    return false
  end

  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["active", "deleted"]
  if @state && !allowed_values.include?(@state)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
end