Class: PureCloud::ManagementUnit
- Inherits:
-
Object
- Object
- PureCloud::ManagementUnit
- Defined in:
- lib/purecloudplatformclientv2/models/management_unit.rb
Overview
Management Unit object for Workforce Management.
Instance Attribute Summary collapse
-
#date_modified ⇒ Object
The date and time at which this management unit was last modified.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#name ⇒ Object
Returns the value of attribute name.
-
#self_uri ⇒ Object
The URI for this object.
-
#start_day_of_week ⇒ Object
Start day of week for workforce management planning purposes.
-
#timezone ⇒ Object
The time zone for the management unit in standard Olson Format (See en.wikipedia.org/wiki/Tz_database).
-
#version ⇒ Object
The version of the underlying ManagementUnit object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementUnit
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementUnit
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'startDayOfWeek') self.start_day_of_week = attributes[:'startDayOfWeek'] end if attributes.has_key?(:'timezone') self.timezone = attributes[:'timezone'] end if attributes.has_key?(:'version') self.version = attributes[:'version'] end if attributes.has_key?(:'dateModified') self.date_modified = attributes[:'dateModified'] end if attributes.has_key?(:'selfUri') self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#date_modified ⇒ Object
The date and time at which this management unit was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
37 38 39 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 37 def date_modified @date_modified end |
#id ⇒ Object
The globally unique identifier for the object.
23 24 25 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 23 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 25 def name @name end |
#self_uri ⇒ Object
The URI for this object
40 41 42 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 40 def self_uri @self_uri end |
#start_day_of_week ⇒ Object
Start day of week for workforce management planning purposes
28 29 30 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 28 def start_day_of_week @start_day_of_week end |
#timezone ⇒ Object
The time zone for the management unit in standard Olson Format (See en.wikipedia.org/wiki/Tz_database)
31 32 33 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 31 def timezone @timezone end |
#version ⇒ Object
The version of the underlying ManagementUnit object. Useful for handling eventual consistency issues. User must submit the current version they of the ManagementUnit in any write requests
34 35 36 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 34 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 43 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'start_day_of_week' => :'startDayOfWeek', :'timezone' => :'timezone', :'version' => :'version', :'date_modified' => :'dateModified', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 56 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'start_day_of_week' => :'String', :'timezone' => :'String', :'version' => :'Integer', :'date_modified' => :'DateTime', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && start_day_of_week == o.start_day_of_week && timezone == o.timezone && version == o.version && date_modified == o.date_modified && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 182 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 242 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 158 def hash [id, name, start_day_of_week, timezone, version, date_modified, self_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 108 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
225 226 227 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 225 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
230 231 232 233 234 235 236 237 238 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
220 221 222 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 220 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/purecloudplatformclientv2/models/management_unit.rb', line 115 def valid? allowed_values = ["Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday"] if @start_day_of_week && !allowed_values.include?(@start_day_of_week) return false end if @version.nil? return false end end |