Class: PureCloud::ObjectsApi
- Inherits:
-
Object
- Object
- PureCloud::ObjectsApi
- Defined in:
- lib/purecloudplatformclientv2/api/objects_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_authorization_divisions_limit(opts = {}) ⇒ Integer
Returns the maximum allowed number of divisions.
-
#get_authorization_divisions_limit_with_http_info(opts = {}) ⇒ Array<(Integer, Fixnum, Hash)>
Returns the maximum allowed number of divisions.
-
#initialize(api_client = ApiClient.default) ⇒ ObjectsApi
constructor
A new instance of ObjectsApi.
-
#post_authorization_division_object(division_id, object_type, body, opts = {}) ⇒ Array<AuthzTypedObject>
Set the division of a list of objects.
-
#post_authorization_division_object_with_http_info(division_id, object_type, body, opts = {}) ⇒ Array<(Array<AuthzTypedObject>, Fixnum, Hash)>
Set the division of a list of objects.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ObjectsApi
Returns a new instance of ObjectsApi.
23 24 25 |
# File 'lib/purecloudplatformclientv2/api/objects_api.rb', line 23 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
21 22 23 |
# File 'lib/purecloudplatformclientv2/api/objects_api.rb', line 21 def api_client @api_client end |
Instance Method Details
#get_authorization_divisions_limit(opts = {}) ⇒ Integer
Returns the maximum allowed number of divisions.
31 32 33 34 |
# File 'lib/purecloudplatformclientv2/api/objects_api.rb', line 31 def (opts = {}) data, _status_code, _headers = (opts) return data end |
#get_authorization_divisions_limit_with_http_info(opts = {}) ⇒ Array<(Integer, Fixnum, Hash)>
Returns the maximum allowed number of divisions.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/purecloudplatformclientv2/api/objects_api.rb', line 40 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ObjectsApi.get_authorization_divisions_limit ..." end # resource path local_var_path = "/api/v2/authorization/divisions/limit".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud Auth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Integer') if @api_client.config.debugging @api_client.config.logger.debug "API called: ObjectsApi#get_authorization_divisions_limit\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_authorization_division_object(division_id, object_type, body, opts = {}) ⇒ Array<AuthzTypedObject>
Set the division of a list of objects. The objects must all be of the same type: CAMPAIGN, CONTACTLIST, DNCLIST, MANAGEMENTUNIT, FLOW, QUEUE, USER
89 90 91 92 |
# File 'lib/purecloudplatformclientv2/api/objects_api.rb', line 89 def (division_id, object_type, body, opts = {}) data, _status_code, _headers = (division_id, object_type, body, opts) return data end |
#post_authorization_division_object_with_http_info(division_id, object_type, body, opts = {}) ⇒ Array<(Array<AuthzTypedObject>, Fixnum, Hash)>
Set the division of a list of objects. The objects must all be of the same type: CAMPAIGN, CONTACTLIST, DNCLIST, MANAGEMENTUNIT, FLOW, QUEUE, USER
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/purecloudplatformclientv2/api/objects_api.rb', line 101 def (division_id, object_type, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ObjectsApi.post_authorization_division_object ..." end # verify the required parameter 'division_id' is set fail ArgumentError, "Missing the required parameter 'division_id' when calling ObjectsApi.post_authorization_division_object" if division_id.nil? # verify the required parameter 'object_type' is set fail ArgumentError, "Missing the required parameter 'object_type' when calling ObjectsApi.post_authorization_division_object" if object_type.nil? # verify enum value unless ['QUEUE', 'CAMPAIGN', 'CONTACTLIST', 'DNCLIST', 'MANAGEMENTUNIT', 'FLOW', 'USER'].include?(object_type) fail ArgumentError, "invalid value for 'object_type', must be one of QUEUE, CAMPAIGN, CONTACTLIST, DNCLIST, MANAGEMENTUNIT, FLOW, USER" end # verify the required parameter 'body' is set fail ArgumentError, "Missing the required parameter 'body' when calling ObjectsApi.post_authorization_division_object" if body.nil? # resource path local_var_path = "/api/v2/authorization/divisions/{divisionId}/objects/{objectType}".sub('{format}','json').sub('{' + 'divisionId' + '}', division_id.to_s).sub('{' + 'objectType' + '}', object_type.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(body) auth_names = ['PureCloud Auth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Array<AuthzTypedObject>') if @api_client.config.debugging @api_client.config.logger.debug "API called: ObjectsApi#post_authorization_division_object\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |