Class: PureCloud::Recording

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/recording.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Recording

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 214

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'id')
    
    
    self.id = attributes[:'id']
    
  
  end

  
  if attributes.has_key?(:'name')
    
    
    self.name = attributes[:'name']
    
  
  end

  
  if attributes.has_key?(:'conversationId')
    
    
    self.conversation_id = attributes[:'conversationId']
    
  
  end

  
  if attributes.has_key?(:'path')
    
    
    self.path = attributes[:'path']
    
  
  end

  
  if attributes.has_key?(:'startTime')
    
    
    self.start_time = attributes[:'startTime']
    
  
  end

  
  if attributes.has_key?(:'endTime')
    
    
    self.end_time = attributes[:'endTime']
    
  
  end

  
  if attributes.has_key?(:'media')
    
    
    self.media = attributes[:'media']
    
  
  end

  
  if attributes.has_key?(:'annotations')
    
    if (value = attributes[:'annotations']).is_a?(Array)
      self.annotations = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'transcript')
    
    if (value = attributes[:'transcript']).is_a?(Array)
      self.transcript = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'emailTranscript')
    
    if (value = attributes[:'emailTranscript']).is_a?(Array)
      self.email_transcript = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'messagingTranscript')
    
    if (value = attributes[:'messagingTranscript']).is_a?(Array)
      self.messaging_transcript = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'fileState')
    
    
    self.file_state = attributes[:'fileState']
    
  
  end

  
  if attributes.has_key?(:'restoreExpirationTime')
    
    
    self.restore_expiration_time = attributes[:'restoreExpirationTime']
    
  
  end

  
  if attributes.has_key?(:'mediaUris')
    
    if (value = attributes[:'mediaUris']).is_a?(Array)
      self.media_uris = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'estimatedTranscodeTimeMs')
    
    
    self.estimated_transcode_time_ms = attributes[:'estimatedTranscodeTimeMs']
    
  
  end

  
  if attributes.has_key?(:'actualTranscodeTimeMs')
    
    
    self.actual_transcode_time_ms = attributes[:'actualTranscodeTimeMs']
    
  
  end

  
  if attributes.has_key?(:'archiveDate')
    
    
    self.archive_date = attributes[:'archiveDate']
    
  
  end

  
  if attributes.has_key?(:'archiveMedium')
    
    
    self.archive_medium = attributes[:'archiveMedium']
    
  
  end

  
  if attributes.has_key?(:'deleteDate')
    
    
    self.delete_date = attributes[:'deleteDate']
    
  
  end

  
  if attributes.has_key?(:'outputDurationMs')
    
    
    self.output_duration_ms = attributes[:'outputDurationMs']
    
  
  end

  
  if attributes.has_key?(:'outputSizeInBytes')
    
    
    self.output_size_in_bytes = attributes[:'outputSizeInBytes']
    
  
  end

  
  if attributes.has_key?(:'maxAllowedRestorationsForOrg')
    
    
    self.max_allowed_restorations_for_org = attributes[:'maxAllowedRestorationsForOrg']
    
  
  end

  
  if attributes.has_key?(:'remainingRestorationsAllowedForOrg')
    
    
    self.remaining_restorations_allowed_for_org = attributes[:'remainingRestorationsAllowedForOrg']
    
  
  end

  
  if attributes.has_key?(:'sessionId')
    
    
    self.session_id = attributes[:'sessionId']
    
  
  end

  
  if attributes.has_key?(:'users')
    
    if (value = attributes[:'users']).is_a?(Array)
      self.users = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'selfUri')
    
    
    self.self_uri = attributes[:'selfUri']
    
  
  end

  
end

Instance Attribute Details

#actual_transcode_time_msObject

Returns the value of attribute actual_transcode_time_ms.



62
63
64
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 62

def actual_transcode_time_ms
  @actual_transcode_time_ms
end

#annotationsObject

Annotations that belong to the recording.



40
41
42
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 40

def annotations
  @annotations
end

#archive_dateObject

The date the recording will be archived. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



65
66
67
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 65

def archive_date
  @archive_date
end

#archive_mediumObject

The type of archive medium used. Example: CloudArchive



68
69
70
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 68

def archive_medium
  @archive_medium
end

#conversation_idObject

Returns the value of attribute conversation_id.



26
27
28
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 26

def conversation_id
  @conversation_id
end

#delete_dateObject

The date the recording will be deleted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



71
72
73
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 71

def delete_date
  @delete_date
end

#email_transcriptObject

Represents an email transcript



46
47
48
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 46

def email_transcript
  @email_transcript
end

#end_timeObject

The end time of the recording. Null when there is no playable media.



34
35
36
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 34

def end_time
  @end_time
end

#estimated_transcode_time_msObject

Returns the value of attribute estimated_transcode_time_ms.



60
61
62
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 60

def estimated_transcode_time_ms
  @estimated_transcode_time_ms
end

#file_stateObject

Represents the current file state for a recording. Examples: Uploading, Archived, etc



52
53
54
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 52

def file_state
  @file_state
end

#idObject

The globally unique identifier for the object.



22
23
24
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 22

def id
  @id
end

#max_allowed_restorations_for_orgObject

How many archive restorations the organization is allowed to have.



80
81
82
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 80

def max_allowed_restorations_for_org
  @max_allowed_restorations_for_org
end

#mediaObject

The type of media that the recording is. At the moment that could be audio, chat, or email.



37
38
39
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 37

def media
  @media
end

#media_urisObject

The different mediaUris for the recording. Null when there is no playable media.



58
59
60
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 58

def media_uris
  @media_uris
end

#messaging_transcriptObject

Represents a messaging transcript



49
50
51
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 49

def messaging_transcript
  @messaging_transcript
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 24

def name
  @name
end

#output_duration_msObject

Duration of transcoded media in milliseconds



74
75
76
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 74

def output_duration_ms
  @output_duration_ms
end

#output_size_in_bytesObject

Size of transcoded media in bytes. 0 if there is no transcoded media.



77
78
79
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 77

def output_size_in_bytes
  @output_size_in_bytes
end

#pathObject

Returns the value of attribute path.



28
29
30
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 28

def path
  @path
end

#remaining_restorations_allowed_for_orgObject

The remaining archive restorations the organization has.



83
84
85
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 83

def remaining_restorations_allowed_for_org
  @remaining_restorations_allowed_for_org
end

#restore_expiration_timeObject

The amount of time a restored recording will remain restored before being archived again. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



55
56
57
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 55

def restore_expiration_time
  @restore_expiration_time
end

#self_uriObject

The URI for this object



92
93
94
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 92

def self_uri
  @self_uri
end

#session_idObject

The session id represents an external resource id, such as email, call, chat, etc



86
87
88
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 86

def session_id
  @session_id
end

#start_timeObject

The start time of the recording. Null when there is no playable media.



31
32
33
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 31

def start_time
  @start_time
end

#transcriptObject

Represents a chat transcript



43
44
45
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 43

def transcript
  @transcript
end

#usersObject

The users participating in the conversation



89
90
91
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 89

def users
  @users
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 95

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'conversation_id' => :'conversationId',
    
    :'path' => :'path',
    
    :'start_time' => :'startTime',
    
    :'end_time' => :'endTime',
    
    :'media' => :'media',
    
    :'annotations' => :'annotations',
    
    :'transcript' => :'transcript',
    
    :'email_transcript' => :'emailTranscript',
    
    :'messaging_transcript' => :'messagingTranscript',
    
    :'file_state' => :'fileState',
    
    :'restore_expiration_time' => :'restoreExpirationTime',
    
    :'media_uris' => :'mediaUris',
    
    :'estimated_transcode_time_ms' => :'estimatedTranscodeTimeMs',
    
    :'actual_transcode_time_ms' => :'actualTranscodeTimeMs',
    
    :'archive_date' => :'archiveDate',
    
    :'archive_medium' => :'archiveMedium',
    
    :'delete_date' => :'deleteDate',
    
    :'output_duration_ms' => :'outputDurationMs',
    
    :'output_size_in_bytes' => :'outputSizeInBytes',
    
    :'max_allowed_restorations_for_org' => :'maxAllowedRestorationsForOrg',
    
    :'remaining_restorations_allowed_for_org' => :'remainingRestorationsAllowedForOrg',
    
    :'session_id' => :'sessionId',
    
    :'users' => :'users',
    
    :'self_uri' => :'selfUri'
    
  }
end

.swagger_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 154

def self.swagger_types
  {
    
    :'id' => :'String',
    
    :'name' => :'String',
    
    :'conversation_id' => :'String',
    
    :'path' => :'String',
    
    :'start_time' => :'String',
    
    :'end_time' => :'String',
    
    :'media' => :'String',
    
    :'annotations' => :'Array<Annotation>',
    
    :'transcript' => :'Array<ChatMessage>',
    
    :'email_transcript' => :'Array<RecordingEmailMessage>',
    
    :'messaging_transcript' => :'Array<RecordingMessagingMessage>',
    
    :'file_state' => :'String',
    
    :'restore_expiration_time' => :'DateTime',
    
    :'media_uris' => :'Hash<String, MediaResult>',
    
    :'estimated_transcode_time_ms' => :'Integer',
    
    :'actual_transcode_time_ms' => :'Integer',
    
    :'archive_date' => :'DateTime',
    
    :'archive_medium' => :'String',
    
    :'delete_date' => :'DateTime',
    
    :'output_duration_ms' => :'Integer',
    
    :'output_size_in_bytes' => :'Integer',
    
    :'max_allowed_restorations_for_org' => :'Integer',
    
    :'remaining_restorations_allowed_for_org' => :'Integer',
    
    :'session_id' => :'String',
    
    :'users' => :'Array<User>',
    
    :'self_uri' => :'String'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 749

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      conversation_id == o.conversation_id &&
      path == o.path &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      media == o.media &&
      annotations == o.annotations &&
      transcript == o.transcript &&
      email_transcript == o.email_transcript &&
      messaging_transcript == o.messaging_transcript &&
      file_state == o.file_state &&
      restore_expiration_time == o.restore_expiration_time &&
      media_uris == o.media_uris &&
      estimated_transcode_time_ms == o.estimated_transcode_time_ms &&
      actual_transcode_time_ms == o.actual_transcode_time_ms &&
      archive_date == o.archive_date &&
      archive_medium == o.archive_medium &&
      delete_date == o.delete_date &&
      output_duration_ms == o.output_duration_ms &&
      output_size_in_bytes == o.output_size_in_bytes &&
      max_allowed_restorations_for_org == o.max_allowed_restorations_for_org &&
      remaining_restorations_allowed_for_org == o.remaining_restorations_allowed_for_org &&
      session_id == o.session_id &&
      users == o.users &&
      self_uri == o.self_uri
end

#_deserialize(type, value) ⇒ Object



812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 812

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



872
873
874
875
876
877
878
879
880
881
882
883
884
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 872

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 793

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


782
783
784
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 782

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



788
789
790
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 788

def hash
  [id, name, conversation_id, path, start_time, end_time, media, annotations, transcript, email_transcript, messaging_transcript, file_state, restore_expiration_time, media_uris, estimated_transcode_time_ms, actual_transcode_time_ms, archive_date, archive_medium, delete_date, output_duration_ms, output_size_in_bytes, max_allowed_restorations_for_org, remaining_restorations_allowed_for_org, session_id, users, self_uri].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



471
472
473
474
475
476
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 471

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



855
856
857
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 855

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



860
861
862
863
864
865
866
867
868
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 860

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



850
851
852
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 850

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/purecloudplatformclientv2/models/recording.rb', line 480

def valid?
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["ARCHIVED", "AVAILABLE", "DELETED", "RESTORED", "RESTORING", "UPLOADING", "ERROR"]
  if @file_state && !allowed_values.include?(@file_state)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["CLOUDARCHIVE"]
  if @archive_medium && !allowed_values.include?(@archive_medium)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
end