Class: PureCloud::RecordingMetadata
- Inherits:
-
Object
- Object
- PureCloud::RecordingMetadata
- Defined in:
- lib/purecloudplatformclientv2/models/recording_metadata.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Object
Annotations that belong to the recording.
-
#archive_date ⇒ Object
The date the recording will be archived.
-
#archive_medium ⇒ Object
The type of archive medium used.
-
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
-
#delete_date ⇒ Object
The date the recording will be deleted.
-
#end_time ⇒ Object
Returns the value of attribute end_time.
-
#file_state ⇒ Object
Represents the current file state for a recording.
-
#id ⇒ Object
The globally unique identifier for the object.
-
#max_allowed_restorations_for_org ⇒ Object
How many archive restorations the organization is allowed to have.
-
#media ⇒ Object
The type of media that the recording is.
-
#name ⇒ Object
Returns the value of attribute name.
-
#path ⇒ Object
Returns the value of attribute path.
-
#remaining_restorations_allowed_for_org ⇒ Object
The remaining archive restorations the organization has.
-
#restore_expiration_time ⇒ Object
The amount of time a restored recording will remain restored before being archived again.
-
#self_uri ⇒ Object
The URI for this object.
-
#session_id ⇒ Object
The session id represents an external resource id, such as email, call, chat, etc.
-
#start_time ⇒ Object
The start time of the recording for screen recordings.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecordingMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RecordingMetadata
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 152 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'conversationId') self.conversation_id = attributes[:'conversationId'] end if attributes.has_key?(:'path') self.path = attributes[:'path'] end if attributes.has_key?(:'startTime') self.start_time = attributes[:'startTime'] end if attributes.has_key?(:'endTime') self.end_time = attributes[:'endTime'] end if attributes.has_key?(:'media') self.media = attributes[:'media'] end if attributes.has_key?(:'annotations') if (value = attributes[:'annotations']).is_a?(Array) self.annotations = value end end if attributes.has_key?(:'fileState') self.file_state = attributes[:'fileState'] end if attributes.has_key?(:'restoreExpirationTime') self.restore_expiration_time = attributes[:'restoreExpirationTime'] end if attributes.has_key?(:'archiveDate') self.archive_date = attributes[:'archiveDate'] end if attributes.has_key?(:'archiveMedium') self.archive_medium = attributes[:'archiveMedium'] end if attributes.has_key?(:'deleteDate') self.delete_date = attributes[:'deleteDate'] end if attributes.has_key?(:'maxAllowedRestorationsForOrg') self.max_allowed_restorations_for_org = attributes[:'maxAllowedRestorationsForOrg'] end if attributes.has_key?(:'remainingRestorationsAllowedForOrg') self.remaining_restorations_allowed_for_org = attributes[:'remainingRestorationsAllowedForOrg'] end if attributes.has_key?(:'sessionId') self.session_id = attributes[:'sessionId'] end if attributes.has_key?(:'selfUri') self.self_uri = attributes[:'selfUri'] end end |
Instance Attribute Details
#annotations ⇒ Object
Annotations that belong to the recording. Populated when recording filestate is AVAILABLE.
39 40 41 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 39 def annotations @annotations end |
#archive_date ⇒ Object
The date the recording will be archived. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
48 49 50 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 48 def archive_date @archive_date end |
#archive_medium ⇒ Object
The type of archive medium used. Example: CloudArchive
51 52 53 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 51 def archive_medium @archive_medium end |
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
26 27 28 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 26 def conversation_id @conversation_id end |
#delete_date ⇒ Object
The date the recording will be deleted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
54 55 56 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 54 def delete_date @delete_date end |
#end_time ⇒ Object
Returns the value of attribute end_time.
33 34 35 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 33 def end_time @end_time end |
#file_state ⇒ Object
Represents the current file state for a recording. Examples: Uploading, Archived, etc
42 43 44 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 42 def file_state @file_state end |
#id ⇒ Object
The globally unique identifier for the object.
22 23 24 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 22 def id @id end |
#max_allowed_restorations_for_org ⇒ Object
How many archive restorations the organization is allowed to have.
57 58 59 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 57 def max_allowed_restorations_for_org @max_allowed_restorations_for_org end |
#media ⇒ Object
The type of media that the recording is. At the moment that could be audio, chat, email, or message.
36 37 38 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 36 def media @media end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 24 def name @name end |
#path ⇒ Object
Returns the value of attribute path.
28 29 30 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 28 def path @path end |
#remaining_restorations_allowed_for_org ⇒ Object
The remaining archive restorations the organization has.
60 61 62 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 60 def remaining_restorations_allowed_for_org @remaining_restorations_allowed_for_org end |
#restore_expiration_time ⇒ Object
The amount of time a restored recording will remain restored before being archived again. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ
45 46 47 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 45 def restore_expiration_time @restore_expiration_time end |
#self_uri ⇒ Object
The URI for this object
66 67 68 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 66 def self_uri @self_uri end |
#session_id ⇒ Object
The session id represents an external resource id, such as email, call, chat, etc
63 64 65 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 63 def session_id @session_id end |
#start_time ⇒ Object
The start time of the recording for screen recordings. Null for other types.
31 32 33 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 31 def start_time @start_time end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 69 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'conversation_id' => :'conversationId', :'path' => :'path', :'start_time' => :'startTime', :'end_time' => :'endTime', :'media' => :'media', :'annotations' => :'annotations', :'file_state' => :'fileState', :'restore_expiration_time' => :'restoreExpirationTime', :'archive_date' => :'archiveDate', :'archive_medium' => :'archiveMedium', :'delete_date' => :'deleteDate', :'max_allowed_restorations_for_org' => :'maxAllowedRestorationsForOrg', :'remaining_restorations_allowed_for_org' => :'remainingRestorationsAllowedForOrg', :'session_id' => :'sessionId', :'self_uri' => :'selfUri' } end |
.swagger_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 110 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'conversation_id' => :'String', :'path' => :'String', :'start_time' => :'String', :'end_time' => :'String', :'media' => :'String', :'annotations' => :'Array<Annotation>', :'file_state' => :'String', :'restore_expiration_time' => :'DateTime', :'archive_date' => :'DateTime', :'archive_medium' => :'String', :'delete_date' => :'DateTime', :'max_allowed_restorations_for_org' => :'Integer', :'remaining_restorations_allowed_for_org' => :'Integer', :'session_id' => :'String', :'self_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 515 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && conversation_id == o.conversation_id && path == o.path && start_time == o.start_time && end_time == o.end_time && media == o.media && annotations == o.annotations && file_state == o.file_state && restore_expiration_time == o.restore_expiration_time && archive_date == o.archive_date && archive_medium == o.archive_medium && delete_date == o.delete_date && max_allowed_restorations_for_org == o.max_allowed_restorations_for_org && remaining_restorations_allowed_for_org == o.remaining_restorations_allowed_for_org && session_id == o.session_id && self_uri == o.self_uri end |
#_deserialize(type, value) ⇒ Object
569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 569 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 629 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 550 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
539 540 541 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 539 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
545 546 547 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 545 def hash [id, name, conversation_id, path, start_time, end_time, media, annotations, file_state, restore_expiration_time, archive_date, archive_medium, delete_date, max_allowed_restorations_for_org, remaining_restorations_allowed_for_org, session_id, self_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
318 319 320 321 322 323 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 318 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
612 613 614 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 612 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
617 618 619 620 621 622 623 624 625 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 617 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
607 608 609 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 607 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/purecloudplatformclientv2/models/recording_metadata.rb', line 327 def valid? allowed_values = ["ARCHIVED", "AVAILABLE", "DELETED", "RESTORED", "RESTORING", "UPLOADING", "ERROR"] if @file_state && !allowed_values.include?(@file_state) return false end allowed_values = ["CLOUDARCHIVE"] if @archive_medium && !allowed_values.include?(@archive_medium) return false end end |