Class: PureCloud::ReportingExportJobRequest
- Inherits:
-
Object
- Object
- PureCloud::ReportingExportJobRequest
- Defined in:
- lib/purecloudplatformclientv2/models/reporting_export_job_request.rb
Instance Attribute Summary collapse
-
#export_format ⇒ Object
The requested format of the exported data.
-
#filter ⇒ Object
Filters to apply to create the view.
-
#has_format_durations ⇒ Object
Indicates if durations are formatted in hh:mm:ss format instead of ms.
-
#interval ⇒ Object
The time period used to limit the the exported data.
-
#locale ⇒ Object
The locale use for localization of the exported data, i.e.
-
#name ⇒ Object
The user supplied name of the export request.
-
#period ⇒ Object
The Period of the request in which to break down the intervals.
-
#read ⇒ Object
Indicates if the request has been marked as read.
-
#time_zone ⇒ Object
The requested timezone of the exported data.
-
#view_type ⇒ Object
The type of view export job to be created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReportingExportJobRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ReportingExportJobRequest
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'timeZone') self.time_zone = attributes[:'timeZone'] end if attributes.has_key?(:'exportFormat') self.export_format = attributes[:'exportFormat'] end if attributes.has_key?(:'interval') self.interval = attributes[:'interval'] end if attributes.has_key?(:'period') self.period = attributes[:'period'] end if attributes.has_key?(:'viewType') self.view_type = attributes[:'viewType'] end if attributes.has_key?(:'filter') self.filter = attributes[:'filter'] end if attributes.has_key?(:'read') self.read = attributes[:'read'] end if attributes.has_key?(:'locale') self.locale = attributes[:'locale'] end if attributes.has_key?(:'hasFormatDurations') self.has_format_durations = attributes[:'hasFormatDurations'] end end |
Instance Attribute Details
#export_format ⇒ Object
The requested format of the exported data
28 29 30 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 28 def export_format @export_format end |
#filter ⇒ Object
Filters to apply to create the view
40 41 42 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 40 def filter @filter end |
#has_format_durations ⇒ Object
Indicates if durations are formatted in hh:mm:ss format instead of ms
49 50 51 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 49 def has_format_durations @has_format_durations end |
#interval ⇒ Object
The time period used to limit the the exported data. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss
31 32 33 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 31 def interval @interval end |
#locale ⇒ Object
The locale use for localization of the exported data, i.e. en-us, es-mx
46 47 48 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 46 def locale @locale end |
#name ⇒ Object
The user supplied name of the export request
22 23 24 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 22 def name @name end |
#period ⇒ Object
The Period of the request in which to break down the intervals. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H
34 35 36 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 34 def period @period end |
#read ⇒ Object
Indicates if the request has been marked as read
43 44 45 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 43 def read @read end |
#time_zone ⇒ Object
The requested timezone of the exported data
25 26 27 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 25 def time_zone @time_zone end |
#view_type ⇒ Object
The type of view export job to be created
37 38 39 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 37 def view_type @view_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 52 def self.attribute_map { :'name' => :'name', :'time_zone' => :'timeZone', :'export_format' => :'exportFormat', :'interval' => :'interval', :'period' => :'period', :'view_type' => :'viewType', :'filter' => :'filter', :'read' => :'read', :'locale' => :'locale', :'has_format_durations' => :'hasFormatDurations' } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 79 def self.swagger_types { :'name' => :'String', :'time_zone' => :'TimeZone', :'export_format' => :'String', :'interval' => :'String', :'period' => :'String', :'view_type' => :'String', :'filter' => :'ViewFilter', :'read' => :'BOOLEAN', :'locale' => :'String', :'has_format_durations' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 372 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && time_zone == o.time_zone && export_format == o.export_format && interval == o.interval && period == o.period && view_type == o.view_type && filter == o.filter && read == o.read && locale == o.locale && has_format_durations == o.has_format_durations end |
#_deserialize(type, value) ⇒ Object
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 419 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 479 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 400 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
389 390 391 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 389 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
395 396 397 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 395 def hash [name, time_zone, export_format, interval, period, view_type, filter, read, locale, has_format_durations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
208 209 210 211 212 213 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 208 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
462 463 464 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 462 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
467 468 469 470 471 472 473 474 475 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 467 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
457 458 459 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 457 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_request.rb', line 217 def valid? if @name.nil? return false end if @time_zone.nil? return false end if @export_format.nil? return false end allowed_values = ["CSV", "PDF"] if @export_format && !allowed_values.include?(@export_format) return false end if @view_type.nil? return false end allowed_values = ["QUEUE_PERFORMANCE_SUMMARY_VIEW", "QUEUE_PERFORMANCE_DETAIL_VIEW", "INTERACTION_SEARCH_VIEW", "AGENT_PERFORMANCE_SUMMARY_VIEW", "AGENT_PERFORMANCE_DETAIL_VIEW", "AGENT_STATUS_SUMMARY_VIEW", "AGENT_STATUS_DETAIL_VIEW", "AGENT_EVALUATION_SUMMARY_VIEW", "AGENT_EVALUATION_DETAIL_VIEW", "AGENT_QUEUE_DETAIL_VIEW", "AGENT_INTERACTION_DETAIL_VIEW", "ABANDON_INSIGHTS_VIEW", "SKILLS_PERFORMANCE_VIEW", "SURVEY_FORM_PERFORMANCE_SUMMARY_VIEW", "SURVEY_FORM_PERFORMANCE_DETAIL_VIEW", "DNIS_PERFORMANCE_SUMMARY_VIEW", "DNIS_PERFORMANCE_DETAIL_VIEW", "WRAP_UP_PERFORMANCE_SUMMARY_VIEW", "AGENT_WRAP_UP_PERFORMANCE_DETAIL_VIEW", "QUEUE_ACTIVITY_SUMMARY_VIEW", "QUEUE_ACTIVITY_DETAIL_VIEW", "AGENT_QUEUE_ACTIVITY_SUMMARY_VIEW", "QUEUE_AGENT_DETAIL_VIEW", "QUEUE_INTERACTION_DETAIL_VIEW", "AGENT_SCHEDULE_DETAIL_VIEW", "IVR_PERFORMANCE_SUMMARY_VIEW", "IVR_PERFORMANCE_DETAIL_VIEW", "ANSWER_INSIGHTS_VIEW", "HANDLE_INSIGHTS_VIEW", "TALK_INSIGHTS_VIEW", "HOLD_INSIGHTS_VIEW", "ACW_INSIGHTS_VIEW", "WAIT_INSIGHTS_VIEW", "AGENT_WRAP_UP_PERFORMANCE_INTERVAL_DETAIL_VIEW", "FLOW_OUTCOME_SUMMARY_VIEW", "FLOW_OUTCOME_PERFORMANCE_DETAIL_VIEW", "FLOW_OUTCOME_PERFORMANCE_INTERVAL_DETAIL_VIEW", "FLOW_DESTINATION_SUMMARY_VIEW", "FLOW_DESTINATION_DETAIL_VIEW", "API_USAGE_VIEW"] if @view_type && !allowed_values.include?(@view_type) return false end if @filter.nil? return false end if @locale.nil? return false end end |