Class: PureCloud::ReportingExportJobResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/reporting_export_job_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReportingExportJobResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 162

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'id')
    
    
    self.id = attributes[:'id']
    
  
  end

  
  if attributes.has_key?(:'name')
    
    
    self.name = attributes[:'name']
    
  
  end

  
  if attributes.has_key?(:'status')
    
    
    self.status = attributes[:'status']
    
  
  end

  
  if attributes.has_key?(:'timeZone')
    
    
    self.time_zone = attributes[:'timeZone']
    
  
  end

  
  if attributes.has_key?(:'exportFormat')
    
    
    self.export_format = attributes[:'exportFormat']
    
  
  end

  
  if attributes.has_key?(:'interval')
    
    
    self.interval = attributes[:'interval']
    
  
  end

  
  if attributes.has_key?(:'downloadUrl')
    
    
    self.download_url = attributes[:'downloadUrl']
    
  
  end

  
  if attributes.has_key?(:'viewType')
    
    
    self.view_type = attributes[:'viewType']
    
  
  end

  
  if attributes.has_key?(:'exportErrorMessagesType')
    
    
    self.export_error_messages_type = attributes[:'exportErrorMessagesType']
    
  
  end

  
  if attributes.has_key?(:'period')
    
    
    self.period = attributes[:'period']
    
  
  end

  
  if attributes.has_key?(:'filter')
    
    
    self.filter = attributes[:'filter']
    
  
  end

  
  if attributes.has_key?(:'read')
    
    
    self.read = attributes[:'read']
    
  
  end

  
  if attributes.has_key?(:'createdDateTime')
    
    
    self.created_date_time = attributes[:'createdDateTime']
    
  
  end

  
  if attributes.has_key?(:'modifiedDateTime')
    
    
    self.modified_date_time = attributes[:'modifiedDateTime']
    
  
  end

  
  if attributes.has_key?(:'locale')
    
    
    self.locale = attributes[:'locale']
    
  
  end

  
  if attributes.has_key?(:'percentageComplete')
    
    
    self.percentage_complete = attributes[:'percentageComplete']
    
  
  end

  
  if attributes.has_key?(:'hasFormatDurations')
    
    
    self.has_format_durations = attributes[:'hasFormatDurations']
    
  
  end

  
  if attributes.has_key?(:'selfUri')
    
    
    self.self_uri = attributes[:'selfUri']
    
  
  end

  
end

Instance Attribute Details

#created_date_timeObject

The created date/time of the request. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



57
58
59
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 57

def created_date_time
  @created_date_time
end

#download_urlObject

The url to download the request if it’s status is completed



39
40
41
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 39

def download_url
  @download_url
end

#export_error_messages_typeObject

The error message in case the export request failed



45
46
47
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 45

def export_error_messages_type
  @export_error_messages_type
end

#export_formatObject

The requested format of the exported data



33
34
35
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 33

def export_format
  @export_format
end

#filterObject

Filters to apply to create the view



51
52
53
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 51

def filter
  @filter
end

#has_format_durationsObject

Indicates if durations are formatted in hh:mm:ss format instead of ms



69
70
71
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 69

def has_format_durations
  @has_format_durations
end

#idObject

The globally unique identifier for the object.



22
23
24
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 22

def id
  @id
end

#intervalObject

The time period used to limit the the exported data. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss



36
37
38
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 36

def interval
  @interval
end

#localeObject

The locale use for localization of the exported data, i.e. en-us, es-mx



63
64
65
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 63

def locale
  @locale
end

#modified_date_timeObject

The last modified date/time of the request. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



60
61
62
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 60

def modified_date_time
  @modified_date_time
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 24

def name
  @name
end

#percentage_completeObject

The percentage of the job that has completed processing



66
67
68
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 66

def percentage_complete
  @percentage_complete
end

#periodObject

The Period of the request in which to break down the intervals. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H



48
49
50
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 48

def period
  @period
end

#readObject

Indicates if the request has been marked as read



54
55
56
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 54

def read
  @read
end

#self_uriObject

The URI for this object



72
73
74
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 72

def self_uri
  @self_uri
end

#statusObject

The current status of the export request



27
28
29
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 27

def status
  @status
end

#time_zoneObject

The requested timezone of the exported data



30
31
32
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 30

def time_zone
  @time_zone
end

#view_typeObject

The type of view export job to be created



42
43
44
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 42

def view_type
  @view_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 75

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'status' => :'status',
    
    :'time_zone' => :'timeZone',
    
    :'export_format' => :'exportFormat',
    
    :'interval' => :'interval',
    
    :'download_url' => :'downloadUrl',
    
    :'view_type' => :'viewType',
    
    :'export_error_messages_type' => :'exportErrorMessagesType',
    
    :'period' => :'period',
    
    :'filter' => :'filter',
    
    :'read' => :'read',
    
    :'created_date_time' => :'createdDateTime',
    
    :'modified_date_time' => :'modifiedDateTime',
    
    :'locale' => :'locale',
    
    :'percentage_complete' => :'percentageComplete',
    
    :'has_format_durations' => :'hasFormatDurations',
    
    :'self_uri' => :'selfUri'
    
  }
end

.swagger_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 118

def self.swagger_types
  {
    
    :'id' => :'String',
    
    :'name' => :'String',
    
    :'status' => :'String',
    
    :'time_zone' => :'TimeZone',
    
    :'export_format' => :'String',
    
    :'interval' => :'String',
    
    :'download_url' => :'String',
    
    :'view_type' => :'String',
    
    :'export_error_messages_type' => :'String',
    
    :'period' => :'String',
    
    :'filter' => :'ViewFilter',
    
    :'read' => :'BOOLEAN',
    
    :'created_date_time' => :'DateTime',
    
    :'modified_date_time' => :'DateTime',
    
    :'locale' => :'String',
    
    :'percentage_complete' => :'Float',
    
    :'has_format_durations' => :'BOOLEAN',
    
    :'self_uri' => :'String'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 619

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      time_zone == o.time_zone &&
      export_format == o.export_format &&
      interval == o.interval &&
      download_url == o.download_url &&
      view_type == o.view_type &&
      export_error_messages_type == o.export_error_messages_type &&
      period == o.period &&
      filter == o.filter &&
      read == o.read &&
      created_date_time == o.created_date_time &&
      modified_date_time == o.modified_date_time &&
      locale == o.locale &&
      percentage_complete == o.percentage_complete &&
      has_format_durations == o.has_format_durations &&
      self_uri == o.self_uri
end

#_deserialize(type, value) ⇒ Object



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 674

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 734

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 655

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


644
645
646
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 644

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



650
651
652
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 650

def hash
  [id, name, status, time_zone, export_format, interval, download_url, view_type, export_error_messages_type, period, filter, read, created_date_time, modified_date_time, locale, percentage_complete, has_format_durations, self_uri].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



335
336
337
338
339
340
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 335

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



717
718
719
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 717

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



722
723
724
725
726
727
728
729
730
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 722

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



712
713
714
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 712

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/purecloudplatformclientv2/models/reporting_export_job_response.rb', line 344

def valid?
  
  
  
  
  
  
  
  
  
  
  if @status.nil?
    return false
  end

  
  
  allowed_values = ["SUBMITTED", "RUNNING", "CANCELLING", "CANCELLED", "COMPLETED", "COMPLETED_WITH_PARTIAL_RESULTS", "FAILED"]
  if @status && !allowed_values.include?(@status)
    return false
  end
  
  
  
  
  if @time_zone.nil?
    return false
  end

  
  
  
  
  
  if @export_format.nil?
    return false
  end

  
  
  allowed_values = ["CSV", "PDF"]
  if @export_format && !allowed_values.include?(@export_format)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
  
  if @view_type.nil?
    return false
  end

  
  
  allowed_values = ["QUEUE_PERFORMANCE_SUMMARY_VIEW", "QUEUE_PERFORMANCE_DETAIL_VIEW", "INTERACTION_SEARCH_VIEW", "AGENT_PERFORMANCE_SUMMARY_VIEW", "AGENT_PERFORMANCE_DETAIL_VIEW", "AGENT_STATUS_SUMMARY_VIEW", "AGENT_STATUS_DETAIL_VIEW", "AGENT_EVALUATION_SUMMARY_VIEW", "AGENT_EVALUATION_DETAIL_VIEW", "AGENT_QUEUE_DETAIL_VIEW", "AGENT_INTERACTION_DETAIL_VIEW", "ABANDON_INSIGHTS_VIEW", "SKILLS_PERFORMANCE_VIEW", "SURVEY_FORM_PERFORMANCE_SUMMARY_VIEW", "SURVEY_FORM_PERFORMANCE_DETAIL_VIEW", "DNIS_PERFORMANCE_SUMMARY_VIEW", "DNIS_PERFORMANCE_DETAIL_VIEW", "WRAP_UP_PERFORMANCE_SUMMARY_VIEW", "AGENT_WRAP_UP_PERFORMANCE_DETAIL_VIEW", "QUEUE_ACTIVITY_SUMMARY_VIEW", "QUEUE_ACTIVITY_DETAIL_VIEW", "AGENT_QUEUE_ACTIVITY_SUMMARY_VIEW", "QUEUE_AGENT_DETAIL_VIEW", "QUEUE_INTERACTION_DETAIL_VIEW", "AGENT_SCHEDULE_DETAIL_VIEW", "IVR_PERFORMANCE_SUMMARY_VIEW", "IVR_PERFORMANCE_DETAIL_VIEW", "ANSWER_INSIGHTS_VIEW", "HANDLE_INSIGHTS_VIEW", "TALK_INSIGHTS_VIEW", "HOLD_INSIGHTS_VIEW", "ACW_INSIGHTS_VIEW", "WAIT_INSIGHTS_VIEW", "AGENT_WRAP_UP_PERFORMANCE_INTERVAL_DETAIL_VIEW", "FLOW_OUTCOME_SUMMARY_VIEW", "FLOW_OUTCOME_PERFORMANCE_DETAIL_VIEW", "FLOW_OUTCOME_PERFORMANCE_INTERVAL_DETAIL_VIEW", "FLOW_DESTINATION_SUMMARY_VIEW", "FLOW_DESTINATION_DETAIL_VIEW", "API_USAGE_VIEW"]
  if @view_type && !allowed_values.include?(@view_type)
    return false
  end
  
  
  
  
  
  allowed_values = ["FAILED_CONVERTING_EXPORT_JOB", "FAILED_NO_DATA_EXPORT_JOB_FOUND", "FAILED_GETTING_DATA_FROM_SERVICE", "FAILED_GENERATING_TEMP_FILE", "FAILED_SAVING_FILE_TO_S3", "FAILED_NOTIFYING_SKYWALKER_OF_DOWNLOAD", "FAILED_BUILDING_DOWNLOAD_URL_FROM_SKYWALKER_RESPONSE", "FAILED_CONVERTING_EXPORT_JOB_TO_QUEUE_PERFORMANCE_JOB", "EXPORT_TYPE_NOT_IMPLEMENTED", "REACHED_MAXIMUM_ATTEMPT_OF_RETRY", "FAILED_LONG_RUNNING_EXPORT"]
  if @export_error_messages_type && !allowed_values.include?(@export_error_messages_type)
    return false
  end
  
  
  
  
  
  
  
  
  if @filter.nil?
    return false
  end

  
  
  
  
  
  if @read.nil?
    return false
  end

  
  
  
  
  
  if @created_date_time.nil?
    return false
  end

  
  
  
  
  
  if @modified_date_time.nil?
    return false
  end

  
  
  
  
  
  if @locale.nil?
    return false
  end

  
  
  
  
  
  if @percentage_complete.nil?
    return false
  end

  
  
  
  
  
  
  
  
  
  
  
  
end