Class: PureCloud::ScheduleGroup

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/schedule_group.rb

Overview

A group of schedules that define the operating hours of an organization.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ScheduleGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 135

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'id')
    
    
    self.id = attributes[:'id']
    
  
  end

  
  if attributes.has_key?(:'name')
    
    
    self.name = attributes[:'name']
    
  
  end

  
  if attributes.has_key?(:'description')
    
    
    self.description = attributes[:'description']
    
  
  end

  
  if attributes.has_key?(:'version')
    
    
    self.version = attributes[:'version']
    
  
  end

  
  if attributes.has_key?(:'dateCreated')
    
    
    self.date_created = attributes[:'dateCreated']
    
  
  end

  
  if attributes.has_key?(:'dateModified')
    
    
    self.date_modified = attributes[:'dateModified']
    
  
  end

  
  if attributes.has_key?(:'modifiedBy')
    
    
    self.modified_by = attributes[:'modifiedBy']
    
  
  end

  
  if attributes.has_key?(:'createdBy')
    
    
    self.created_by = attributes[:'createdBy']
    
  
  end

  
  if attributes.has_key?(:'state')
    
    
    self.state = attributes[:'state']
    
  
  end

  
  if attributes.has_key?(:'modifiedByApp')
    
    
    self.modified_by_app = attributes[:'modifiedByApp']
    
  
  end

  
  if attributes.has_key?(:'createdByApp')
    
    
    self.created_by_app = attributes[:'createdByApp']
    
  
  end

  
  if attributes.has_key?(:'timeZone')
    
    
    self.time_zone = attributes[:'timeZone']
    
  
  end

  
  if attributes.has_key?(:'openSchedules')
    
    if (value = attributes[:'openSchedules']).is_a?(Array)
      self.open_schedules = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'closedSchedules')
    
    if (value = attributes[:'closedSchedules']).is_a?(Array)
      self.closed_schedules = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'selfUri')
    
    
    self.self_uri = attributes[:'selfUri']
    
  
  end

  
end

Instance Attribute Details

#closed_schedulesObject

The schedules defining the hours an organization is closed.



54
55
56
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 54

def closed_schedules
  @closed_schedules
end

#created_byObject

Returns the value of attribute created_by.



39
40
41
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 39

def created_by
  @created_by
end

#created_by_appObject

Returns the value of attribute created_by_app.



45
46
47
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 45

def created_by_app
  @created_by_app
end

#date_createdObject

Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



32
33
34
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 32

def date_created
  @date_created
end

#date_modifiedObject

Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



35
36
37
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 35

def date_modified
  @date_modified
end

#descriptionObject

Returns the value of attribute description.



27
28
29
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 27

def description
  @description
end

#idObject

The globally unique identifier for the object.



23
24
25
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 23

def id
  @id
end

#modified_byObject

Returns the value of attribute modified_by.



37
38
39
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 37

def modified_by
  @modified_by
end

#modified_by_appObject

Returns the value of attribute modified_by_app.



43
44
45
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 43

def modified_by_app
  @modified_by_app
end

#nameObject

Returns the value of attribute name.



25
26
27
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 25

def name
  @name
end

#open_schedulesObject

The schedules defining the hours an organization is open.



51
52
53
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 51

def open_schedules
  @open_schedules
end

#self_uriObject

The URI for this object



57
58
59
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 57

def self_uri
  @self_uri
end

#stateObject

Returns the value of attribute state.



41
42
43
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 41

def state
  @state
end

#time_zoneObject

The timezone the schedules are a part of. This is not a schedule property to allow a schedule to be used in multiple timezones.



48
49
50
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 48

def time_zone
  @time_zone
end

#versionObject

Returns the value of attribute version.



29
30
31
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 29

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 60

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'description' => :'description',
    
    :'version' => :'version',
    
    :'date_created' => :'dateCreated',
    
    :'date_modified' => :'dateModified',
    
    :'modified_by' => :'modifiedBy',
    
    :'created_by' => :'createdBy',
    
    :'state' => :'state',
    
    :'modified_by_app' => :'modifiedByApp',
    
    :'created_by_app' => :'createdByApp',
    
    :'time_zone' => :'timeZone',
    
    :'open_schedules' => :'openSchedules',
    
    :'closed_schedules' => :'closedSchedules',
    
    :'self_uri' => :'selfUri'
    
  }
end

.swagger_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 97

def self.swagger_types
  {
    
    :'id' => :'String',
    
    :'name' => :'String',
    
    :'description' => :'String',
    
    :'version' => :'Integer',
    
    :'date_created' => :'DateTime',
    
    :'date_modified' => :'DateTime',
    
    :'modified_by' => :'String',
    
    :'created_by' => :'String',
    
    :'state' => :'String',
    
    :'modified_by_app' => :'String',
    
    :'created_by_app' => :'String',
    
    :'time_zone' => :'String',
    
    :'open_schedules' => :'Array<UriReference>',
    
    :'closed_schedules' => :'Array<UriReference>',
    
    :'self_uri' => :'String'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 450

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      version == o.version &&
      date_created == o.date_created &&
      date_modified == o.date_modified &&
      modified_by == o.modified_by &&
      created_by == o.created_by &&
      state == o.state &&
      modified_by_app == o.modified_by_app &&
      created_by_app == o.created_by_app &&
      time_zone == o.time_zone &&
      open_schedules == o.open_schedules &&
      closed_schedules == o.closed_schedules &&
      self_uri == o.self_uri
end

#_deserialize(type, value) ⇒ Object



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 502

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



562
563
564
565
566
567
568
569
570
571
572
573
574
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 562

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 483

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


472
473
474
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 472

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



478
479
480
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 478

def hash
  [id, name, description, version, date_created, date_modified, modified_by, created_by, state, modified_by_app, created_by_app, time_zone, open_schedules, closed_schedules, self_uri].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



285
286
287
288
289
290
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 285

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



545
546
547
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 545

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



550
551
552
553
554
555
556
557
558
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 550

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



540
541
542
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 540

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/purecloudplatformclientv2/models/schedule_group.rb', line 294

def valid?
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  allowed_values = ["active", "inactive", "deleted"]
  if @state && !allowed_values.include?(@state)
    return false
  end
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
end