Class: PureCloud::ScimV2User

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/scim_v2_user.rb

Overview

SCIM V2 User

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ScimV2User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 142

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'id')
    
    
    self.id = attributes[:'id']
    
  
  end

  
  if attributes.has_key?(:'schemas')
    
    if (value = attributes[:'schemas']).is_a?(Array)
      self.schemas = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'active')
    
    
    self.active = attributes[:'active']
    
  
  end

  
  if attributes.has_key?(:'userName')
    
    
    self.user_name = attributes[:'userName']
    
  
  end

  
  if attributes.has_key?(:'displayName')
    
    
    self.display_name = attributes[:'displayName']
    
  
  end

  
  if attributes.has_key?(:'password')
    
    
    self.password = attributes[:'password']
    
  
  end

  
  if attributes.has_key?(:'title')
    
    
    self.title = attributes[:'title']
    
  
  end

  
  if attributes.has_key?(:'phoneNumbers')
    
    if (value = attributes[:'phoneNumbers']).is_a?(Array)
      self.phone_numbers = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'emails')
    
    if (value = attributes[:'emails']).is_a?(Array)
      self.emails = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'photos')
    
    if (value = attributes[:'photos']).is_a?(Array)
      self.photos = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'externalId')
    
    
    self.external_id = attributes[:'externalId']
    
  
  end

  
  if attributes.has_key?(:'groups')
    
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'roles')
    
    if (value = attributes[:'roles']).is_a?(Array)
      self.roles = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'urn:ietf:params:scim:schemas:extension:enterprise:2.0:User')
    
    
    self.urnietfparamsscimschemasextensionenterprise2_0_user = attributes[:'urn:ietf:params:scim:schemas:extension:enterprise:2.0:User']
    
  
  end

  
  if attributes.has_key?(:'meta')
    
    
    self.meta = attributes[:'meta']
    
  
  end

  
end

Instance Attribute Details

#activeObject

Indicates whether the user’s administrative status is active.



29
30
31
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 29

def active
  @active
end

#display_nameObject

The display name for the user.



35
36
37
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 35

def display_name
  @display_name
end

#emailsObject

A list of the user’s email addresses.



47
48
49
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 47

def emails
  @emails
end

#external_idObject

The external ID of the user. Set by the provisioning client. caseExact is set to true. mutability is set to readWrite.



53
54
55
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 53

def external_id
  @external_id
end

#groupsObject

A list of groups that the user is a member of.



56
57
58
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 56

def groups
  @groups
end

#idObject

The ID of the SCIM resource. Set by the service provider. caseExact is set to true. Mutability is set to readOnly. Returned is set to always.



23
24
25
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 23

def id
  @id
end

#metaObject

Resource SCIM meta



64
65
66
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 64

def meta
  @meta
end

#passwordObject

A new password for a PureCloud user. Does not return an existing password.



38
39
40
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 38

def password
  @password
end

#phone_numbersObject

A list of the user’s phone numbers.



44
45
46
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 44

def phone_numbers
  @phone_numbers
end

#photosObject

A list of the user’s photos.



50
51
52
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 50

def photos
  @photos
end

#rolesObject

A list of roles assigned to the user.



59
60
61
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 59

def roles
  @roles
end

#schemasObject

The list of supported schemas.



26
27
28
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 26

def schemas
  @schemas
end

#titleObject

The user’s title.



41
42
43
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 41

def title
  @title
end

#urnietfparamsscimschemasextensionenterprise2_0_userObject

Returns the value of attribute urnietfparamsscimschemasextensionenterprise2_0_user.



61
62
63
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 61

def urnietfparamsscimschemasextensionenterprise2_0_user
  @urnietfparamsscimschemasextensionenterprise2_0_user
end

#user_nameObject

The user’s PureCloud email address. Must be unique.



32
33
34
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 32

def user_name
  @user_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 67

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'schemas' => :'schemas',
    
    :'active' => :'active',
    
    :'user_name' => :'userName',
    
    :'display_name' => :'displayName',
    
    :'password' => :'password',
    
    :'title' => :'title',
    
    :'phone_numbers' => :'phoneNumbers',
    
    :'emails' => :'emails',
    
    :'photos' => :'photos',
    
    :'external_id' => :'externalId',
    
    :'groups' => :'groups',
    
    :'roles' => :'roles',
    
    :'urnietfparamsscimschemasextensionenterprise2_0_user' => :'urn:ietf:params:scim:schemas:extension:enterprise:2.0:User',
    
    :'meta' => :'meta'
    
  }
end

.swagger_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 104

def self.swagger_types
  {
    
    :'id' => :'String',
    
    :'schemas' => :'Array<String>',
    
    :'active' => :'BOOLEAN',
    
    :'user_name' => :'String',
    
    :'display_name' => :'String',
    
    :'password' => :'String',
    
    :'title' => :'String',
    
    :'phone_numbers' => :'Array<ScimPhoneNumber>',
    
    :'emails' => :'Array<ScimEmail>',
    
    :'photos' => :'Array<Photo>',
    
    :'external_id' => :'String',
    
    :'groups' => :'Array<ScimV2GroupReference>',
    
    :'roles' => :'Array<String>',
    
    :'urnietfparamsscimschemasextensionenterprise2_0_user' => :'ScimV2EnterpriseUser',
    
    :'meta' => :'ScimMetadata'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 451

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      schemas == o.schemas &&
      active == o.active &&
      user_name == o.user_name &&
      display_name == o.display_name &&
      password == o.password &&
      title == o.title &&
      phone_numbers == o.phone_numbers &&
      emails == o.emails &&
      photos == o.photos &&
      external_id == o.external_id &&
      groups == o.groups &&
      roles == o.roles &&
      urnietfparamsscimschemasextensionenterprise2_0_user == o.urnietfparamsscimschemasextensionenterprise2_0_user &&
      meta == o.meta
end

#_deserialize(type, value) ⇒ Object



503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 503

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 563

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 484

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


473
474
475
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 473

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



479
480
481
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 479

def hash
  [id, schemas, active, user_name, display_name, password, title, phone_numbers, emails, photos, external_id, groups, roles, urnietfparamsscimschemasextensionenterprise2_0_user, meta].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



300
301
302
303
304
305
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 300

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_bodyObject

to_body is an alias to to_body (backward compatibility))



546
547
548
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 546

def to_body
  to_hash
end

#to_hashObject

return the object in the form of hash



551
552
553
554
555
556
557
558
559
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 551

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sObject



541
542
543
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 541

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/purecloudplatformclientv2/models/scim_v2_user.rb', line 309

def valid?
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
end