Class: PureCloud::UserPresenceAlert

Inherits:
Object
  • Object
show all
Defined in:
lib/purecloudplatformclientv2/models/user_presence_alert.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserPresenceAlert

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 127

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  
  if attributes.has_key?(:'id')
    
    
    self.id = attributes[:'id']
    
  
  end

  
  if attributes.has_key?(:'name')
    
    
    self.name = attributes[:'name']
    
  
  end

  
  if attributes.has_key?(:'presenceUser')
    
    
    self.presence_user = attributes[:'presenceUser']
    
  
  end

  
  if attributes.has_key?(:'presenceType')
    
    
    self.presence_type = attributes[:'presenceType']
    
  
  end

  
  if attributes.has_key?(:'presenceValue')
    
    
    self.presence_value = attributes[:'presenceValue']
    
  
  end

  
  if attributes.has_key?(:'presenceLimitInSeconds')
    
    
    self.presence_limit_in_seconds = attributes[:'presenceLimitInSeconds']
    
  
  end

  
  if attributes.has_key?(:'ruleId')
    
    
    self.rule_id = attributes[:'ruleId']
    
  
  end

  
  if attributes.has_key?(:'startDate')
    
    
    self.start_date = attributes[:'startDate']
    
  
  end

  
  if attributes.has_key?(:'endDate')
    
    
    self.end_date = attributes[:'endDate']
    
  
  end

  
  if attributes.has_key?(:'notificationUsers')
    
    if (value = attributes[:'notificationUsers']).is_a?(Array)
      self.notification_users = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'alertTypes')
    
    if (value = attributes[:'alertTypes']).is_a?(Array)
      self.alert_types = value
    end
    
    
  
  end

  
  if attributes.has_key?(:'ruleUri')
    
    
    self.rule_uri = attributes[:'ruleUri']
    
  
  end

  
  if attributes.has_key?(:'selfUri')
    
    
    self.self_uri = attributes[:'selfUri']
    
  
  end

  
end

Instance Attribute Details

#alert_types ⇒ Object

A collection of notification methods.



52
53
54
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 52

def alert_types
  @alert_types
end

#end_date ⇒ Object

The date/time the owning rule exiting in alarm status. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



46
47
48
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 46

def end_date
  @end_date
end

#id ⇒ Object

The globally unique identifier for the object.



22
23
24
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 22

def id
  @id
end

#name ⇒ Object

Name of the rule



25
26
27
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 25

def name
  @name
end

#notification_users ⇒ Object

The ids of users who were notified of alarm state change.



49
50
51
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 49

def notification_users
  @notification_users
end

#presence_limit_in_seconds ⇒ Object

The number of seconds to wait before alerting based upon the user's presence.



37
38
39
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 37

def presence_limit_in_seconds
  @presence_limit_in_seconds
end

#presence_type ⇒ Object

Indicates to which presence type the presence value belongs.



31
32
33
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 31

def presence_type
  @presence_type
end

#presence_user ⇒ Object

The user whose presence will be watched.



28
29
30
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 28

def presence_user
  @presence_user
end

#presence_value ⇒ Object

The Org's UUID or Systems enum constance indicating the presence of concern.



34
35
36
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 34

def presence_value
  @presence_value
end

#rule_id ⇒ Object

The id of the rule.



40
41
42
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 40

def rule_id
  @rule_id
end

#rule_uri ⇒ Object

Returns the value of attribute rule_uri.



54
55
56
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 54

def rule_uri
  @rule_uri
end

#self_uri ⇒ Object

The URI for this object



57
58
59
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 57

def self_uri
  @self_uri
end

#start_date ⇒ Object

The date/time the alert was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ



43
44
45
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 43

def start_date
  @start_date
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 60

def self.attribute_map
  {
    
    :'id' => :'id',
    
    :'name' => :'name',
    
    :'presence_user' => :'presenceUser',
    
    :'presence_type' => :'presenceType',
    
    :'presence_value' => :'presenceValue',
    
    :'presence_limit_in_seconds' => :'presenceLimitInSeconds',
    
    :'rule_id' => :'ruleId',
    
    :'start_date' => :'startDate',
    
    :'end_date' => :'endDate',
    
    :'notification_users' => :'notificationUsers',
    
    :'alert_types' => :'alertTypes',
    
    :'rule_uri' => :'ruleUri',
    
    :'self_uri' => :'selfUri'
    
  }
end

.swagger_types ⇒ Object

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 93

def self.swagger_types
  {
    
    :'id' => :'String',
    
    :'name' => :'String',
    
    :'presence_user' => :'User',
    
    :'presence_type' => :'String',
    
    :'presence_value' => :'String',
    
    :'presence_limit_in_seconds' => :'Integer',
    
    :'rule_id' => :'String',
    
    :'start_date' => :'DateTime',
    
    :'end_date' => :'DateTime',
    
    :'notification_users' => :'Array<User>',
    
    :'alert_types' => :'Array<String>',
    
    :'rule_uri' => :'String',
    
    :'self_uri' => :'String'
    
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 451

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      presence_user == o.presence_user &&
      presence_type == o.presence_type &&
      presence_value == o.presence_value &&
      presence_limit_in_seconds == o.presence_limit_in_seconds &&
      rule_id == o.rule_id &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      notification_users == o.notification_users &&
      alert_types == o.alert_types &&
      rule_uri == o.rule_uri &&
      self_uri == o.self_uri
end

#_deserialize(type, value) ⇒ Object



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 501

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    _model = Object.const_get("PureCloud").const_get(type).new
    _model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Object

Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 561

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

build the object from hash



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 482

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      else
        #TODO show warning in debug mode
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    else
      # data not found in attributes(hash), not an issue as the data can be optional
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


471
472
473
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 471

def eql?(o)
  self == o
end

#hash ⇒ Fixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum) —

    Hash code



477
478
479
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 477

def hash
  [id, name, presence_user, presence_type, presence_value, presence_limit_in_seconds, rule_id, start_date, end_date, notification_users, alert_types, rule_uri, self_uri].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



259
260
261
262
263
264
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 259

def list_invalid_properties
  invalid_properties = Array.new
  
  
  return invalid_properties
end

#to_body ⇒ Object

to_body is an alias to to_body (backward compatibility))



544
545
546
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 544

def to_body
  to_hash
end

#to_hash ⇒ Object

return the object in the form of hash



549
550
551
552
553
554
555
556
557
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 549

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ Object



539
540
541
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 539

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/purecloudplatformclientv2/models/user_presence_alert.rb', line 268

def valid?
  
  
  
  
  
  
  if @name.nil?
    return false
  end

  
  
  
  
  
  if @presence_user.nil?
    return false
  end

  
  
  
  
  
  if @presence_type.nil?
    return false
  end

  
  
  allowed_values = ["SYSTEM", "ORGANIZATION"]
  if @presence_type && !allowed_values.include?(@presence_type)
    return false
  end
  
  
  
  
  if @presence_value.nil?
    return false
  end

  
  
  
  
  
  if @presence_limit_in_seconds.nil?
    return false
  end

  
  
  
  
  
  if @rule_id.nil?
    return false
  end

  
  
  
  
  
  if @start_date.nil?
    return false
  end

  
  
  
  
  
  
  
  
  
  if @notification_users.nil?
    return false
  end

  
  
  
  
  
  if @alert_types.nil?
    return false
  end

  
  
  
  
  
  
  
  
  
  
  
  
end