Class: PureCloud::ViewFilter
- Inherits:
-
Object
- Object
- PureCloud::ViewFilter
- Defined in:
- lib/purecloudplatformclientv2/models/view_filter.rb
Instance Attribute Summary collapse
-
#address_tos ⇒ Object
The address To values used to filter the data export request.
-
#directions ⇒ Object
The directions used to filter the data export request.
-
#dnis_list ⇒ Object
The dnis list used to filter the data export request.
-
#language_ids ⇒ Object
The language ids used to filter the data export request.
-
#media_types ⇒ Object
The media types used to filter the data export request.
-
#outbound_campaign_ids ⇒ Object
The outbound campaign ids used to filter the data export request.
-
#outbound_contact_list_ids ⇒ Object
The outbound contact list ids used to filter the data export request.
-
#queue_ids ⇒ Object
The queue ids used to filter the data export request.
-
#skill_ids ⇒ Object
The skill ids used to filter the data export request.
-
#user_ids ⇒ Object
The user ids used to filter the data export request.
-
#wrap_up_codes ⇒ Object
The wrap up codes used to filter the data export request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #_deserialize(type, value) ⇒ Object
-
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
build the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ViewFilter
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility)).
-
#to_hash ⇒ Object
return the object in the form of hash.
- #to_s ⇒ Object
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ViewFilter
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'mediaTypes') if (value = attributes[:'mediaTypes']).is_a?(Array) self.media_types = value end end if attributes.has_key?(:'queueIds') if (value = attributes[:'queueIds']).is_a?(Array) self.queue_ids = value end end if attributes.has_key?(:'skillIds') if (value = attributes[:'skillIds']).is_a?(Array) self.skill_ids = value end end if attributes.has_key?(:'languageIds') if (value = attributes[:'languageIds']).is_a?(Array) self.language_ids = value end end if attributes.has_key?(:'directions') if (value = attributes[:'directions']).is_a?(Array) self.directions = value end end if attributes.has_key?(:'wrapUpCodes') if (value = attributes[:'wrapUpCodes']).is_a?(Array) self.wrap_up_codes = value end end if attributes.has_key?(:'dnisList') if (value = attributes[:'dnisList']).is_a?(Array) self.dnis_list = value end end if attributes.has_key?(:'userIds') if (value = attributes[:'userIds']).is_a?(Array) self.user_ids = value end end if attributes.has_key?(:'addressTos') if (value = attributes[:'addressTos']).is_a?(Array) self.address_tos = value end end if attributes.has_key?(:'outboundCampaignIds') if (value = attributes[:'outboundCampaignIds']).is_a?(Array) self.outbound_campaign_ids = value end end if attributes.has_key?(:'outboundContactListIds') if (value = attributes[:'outboundContactListIds']).is_a?(Array) self.outbound_contact_list_ids = value end end end |
Instance Attribute Details
#address_tos ⇒ Object
The address To values used to filter the data export request
46 47 48 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 46 def address_tos @address_tos end |
#directions ⇒ Object
The directions used to filter the data export request
34 35 36 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 34 def directions @directions end |
#dnis_list ⇒ Object
The dnis list used to filter the data export request
40 41 42 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 40 def dnis_list @dnis_list end |
#language_ids ⇒ Object
The language ids used to filter the data export request
31 32 33 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 31 def language_ids @language_ids end |
#media_types ⇒ Object
The media types used to filter the data export request
22 23 24 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 22 def media_types @media_types end |
#outbound_campaign_ids ⇒ Object
The outbound campaign ids used to filter the data export request
49 50 51 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 49 def outbound_campaign_ids @outbound_campaign_ids end |
#outbound_contact_list_ids ⇒ Object
The outbound contact list ids used to filter the data export request
52 53 54 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 52 def outbound_contact_list_ids @outbound_contact_list_ids end |
#queue_ids ⇒ Object
The queue ids used to filter the data export request
25 26 27 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 25 def queue_ids @queue_ids end |
#skill_ids ⇒ Object
The skill ids used to filter the data export request
28 29 30 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 28 def skill_ids @skill_ids end |
#user_ids ⇒ Object
The user ids used to filter the data export request
43 44 45 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 43 def user_ids @user_ids end |
#wrap_up_codes ⇒ Object
The wrap up codes used to filter the data export request
37 38 39 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 37 def wrap_up_codes @wrap_up_codes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 55 def self.attribute_map { :'media_types' => :'mediaTypes', :'queue_ids' => :'queueIds', :'skill_ids' => :'skillIds', :'language_ids' => :'languageIds', :'directions' => :'directions', :'wrap_up_codes' => :'wrapUpCodes', :'dnis_list' => :'dnisList', :'user_ids' => :'userIds', :'address_tos' => :'addressTos', :'outbound_campaign_ids' => :'outboundCampaignIds', :'outbound_contact_list_ids' => :'outboundContactListIds' } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 84 def self.swagger_types { :'media_types' => :'Array<String>', :'queue_ids' => :'Array<String>', :'skill_ids' => :'Array<String>', :'language_ids' => :'Array<String>', :'directions' => :'Array<String>', :'wrap_up_codes' => :'Array<String>', :'dnis_list' => :'Array<String>', :'user_ids' => :'Array<String>', :'address_tos' => :'Array<String>', :'outbound_campaign_ids' => :'Array<String>', :'outbound_contact_list_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 361 def ==(o) return true if self.equal?(o) self.class == o.class && media_types == o.media_types && queue_ids == o.queue_ids && skill_ids == o.skill_ids && language_ids == o.language_ids && directions == o.directions && wrap_up_codes == o.wrap_up_codes && dnis_list == o.dnis_list && user_ids == o.user_ids && address_tos == o.address_tos && outbound_campaign_ids == o.outbound_campaign_ids && outbound_contact_list_ids == o.outbound_contact_list_ids end |
#_deserialize(type, value) ⇒ Object
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 409 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model _model = Object.const_get("PureCloud").const_get(type).new _model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Object
Method to output non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 469 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
build the object from hash
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 390 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) else #TODO show warning in debug mode end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) else # data not found in attributes(hash), not an issue as the data can be optional end end self end |
#eql?(o) ⇒ Boolean
379 380 381 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 379 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
385 386 387 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 385 def hash [media_types, queue_ids, skill_ids, language_ids, directions, wrap_up_codes, dnis_list, user_ids, address_tos, outbound_campaign_ids, outbound_contact_list_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
246 247 248 249 250 251 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 246 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Object
to_body is an alias to to_body (backward compatibility))
452 453 454 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 452 def to_body to_hash end |
#to_hash ⇒ Object
return the object in the form of hash
457 458 459 460 461 462 463 464 465 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 457 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ Object
447 448 449 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 447 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/purecloudplatformclientv2/models/view_filter.rb', line 255 def valid? end |