Class: PureCloud::AuditApi
- Inherits:
-
Object
- Object
- PureCloud::AuditApi
- Defined in:
- lib/purecloudplatformclientv2/api/audit_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_audits_query_realtime_servicemapping(opts = {}) ⇒ AuditQueryServiceMapping
Get service mapping information used in audits.
-
#get_audits_query_realtime_servicemapping_with_http_info(opts = {}) ⇒ Array<(AuditQueryServiceMapping, Fixnum, Hash)>
Get service mapping information used in audits.
-
#get_audits_query_servicemapping(opts = {}) ⇒ AuditQueryServiceMapping
Get service mapping information used in audits.
-
#get_audits_query_servicemapping_with_http_info(opts = {}) ⇒ Array<(AuditQueryServiceMapping, Fixnum, Hash)>
Get service mapping information used in audits.
-
#get_audits_query_transaction_id(transaction_id, opts = {}) ⇒ AuditQueryExecutionStatusResponse
Get status of audit query execution.
-
#get_audits_query_transaction_id_results(transaction_id, opts = {}) ⇒ AuditQueryExecutionResultsResponse
Get results of audit query.
-
#get_audits_query_transaction_id_results_with_http_info(transaction_id, opts = {}) ⇒ Array<(AuditQueryExecutionResultsResponse, Fixnum, Hash)>
Get results of audit query.
-
#get_audits_query_transaction_id_with_http_info(transaction_id, opts = {}) ⇒ Array<(AuditQueryExecutionStatusResponse, Fixnum, Hash)>
Get status of audit query execution.
-
#initialize(api_client = ApiClient.default) ⇒ AuditApi
constructor
A new instance of AuditApi.
-
#post_audits_query(body, opts = {}) ⇒ AuditQueryExecutionStatusResponse
Create audit query execution.
-
#post_audits_query_realtime(body, opts = {}) ⇒ AuditRealtimeQueryResultsResponse
This endpoint will only retrieve 7 days worth of audits for certain services.
-
#post_audits_query_realtime_with_http_info(body, opts = {}) ⇒ Array<(AuditRealtimeQueryResultsResponse, Fixnum, Hash)>
This endpoint will only retrieve 7 days worth of audits for certain services.
-
#post_audits_query_with_http_info(body, opts = {}) ⇒ Array<(AuditQueryExecutionStatusResponse, Fixnum, Hash)>
Create audit query execution.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuditApi
Returns a new instance of AuditApi.
23 24 25 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 23 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
21 22 23 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 21 def api_client @api_client end |
Instance Method Details
#get_audits_query_realtime_servicemapping(opts = {}) ⇒ AuditQueryServiceMapping
Get service mapping information used in audits.
31 32 33 34 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 31 def get_audits_query_realtime_servicemapping(opts = {}) data, _status_code, _headers = get_audits_query_realtime_servicemapping_with_http_info(opts) return data end |
#get_audits_query_realtime_servicemapping_with_http_info(opts = {}) ⇒ Array<(AuditQueryServiceMapping, Fixnum, Hash)>
Get service mapping information used in audits.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 40 def get_audits_query_realtime_servicemapping_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditApi.get_audits_query_realtime_servicemapping ..." end # resource path local_var_path = "/api/v2/audits/query/realtime/servicemapping".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditQueryServiceMapping') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#get_audits_query_realtime_servicemapping\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audits_query_servicemapping(opts = {}) ⇒ AuditQueryServiceMapping
Get service mapping information used in audits.
86 87 88 89 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 86 def get_audits_query_servicemapping(opts = {}) data, _status_code, _headers = get_audits_query_servicemapping_with_http_info(opts) return data end |
#get_audits_query_servicemapping_with_http_info(opts = {}) ⇒ Array<(AuditQueryServiceMapping, Fixnum, Hash)>
Get service mapping information used in audits.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 95 def get_audits_query_servicemapping_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditApi.get_audits_query_servicemapping ..." end # resource path local_var_path = "/api/v2/audits/query/servicemapping".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditQueryServiceMapping') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#get_audits_query_servicemapping\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audits_query_transaction_id(transaction_id, opts = {}) ⇒ AuditQueryExecutionStatusResponse
Get status of audit query execution
142 143 144 145 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 142 def get_audits_query_transaction_id(transaction_id, opts = {}) data, _status_code, _headers = get_audits_query_transaction_id_with_http_info(transaction_id, opts) return data end |
#get_audits_query_transaction_id_results(transaction_id, opts = {}) ⇒ AuditQueryExecutionResultsResponse
Get results of audit query
210 211 212 213 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 210 def get_audits_query_transaction_id_results(transaction_id, opts = {}) data, _status_code, _headers = get_audits_query_transaction_id_results_with_http_info(transaction_id, opts) return data end |
#get_audits_query_transaction_id_results_with_http_info(transaction_id, opts = {}) ⇒ Array<(AuditQueryExecutionResultsResponse, Fixnum, Hash)>
Get results of audit query
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 223 def get_audits_query_transaction_id_results_with_http_info(transaction_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditApi.get_audits_query_transaction_id_results ..." end # verify the required parameter 'transaction_id' is set fail ArgumentError, "Missing the required parameter 'transaction_id' when calling AuditApi.get_audits_query_transaction_id_results" if transaction_id.nil? # resource path local_var_path = "/api/v2/audits/query/{transactionId}/results".sub('{format}','json').sub('{' + 'transactionId' + '}', transaction_id.to_s) # query parameters query_params = {} query_params[:'cursor'] = opts[:'cursor'] if opts[:'cursor'] query_params[:'pageSize'] = opts[:'page_size'] if opts[:'page_size'] query_params[:'expand'] = @api_client.build_collection_param(opts[:'expand'], :multi) if opts[:'expand'] # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditQueryExecutionResultsResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#get_audits_query_transaction_id_results\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audits_query_transaction_id_with_http_info(transaction_id, opts = {}) ⇒ Array<(AuditQueryExecutionStatusResponse, Fixnum, Hash)>
Get status of audit query execution
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 152 def get_audits_query_transaction_id_with_http_info(transaction_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditApi.get_audits_query_transaction_id ..." end # verify the required parameter 'transaction_id' is set fail ArgumentError, "Missing the required parameter 'transaction_id' when calling AuditApi.get_audits_query_transaction_id" if transaction_id.nil? # resource path local_var_path = "/api/v2/audits/query/{transactionId}".sub('{format}','json').sub('{' + 'transactionId' + '}', transaction_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditQueryExecutionStatusResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#get_audits_query_transaction_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_audits_query(body, opts = {}) ⇒ AuditQueryExecutionStatusResponse
Create audit query execution
299 300 301 302 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 299 def post_audits_query(body, opts = {}) data, _status_code, _headers = post_audits_query_with_http_info(body, opts) return data end |
#post_audits_query_realtime(body, opts = {}) ⇒ AuditRealtimeQueryResultsResponse
This endpoint will only retrieve 7 days worth of audits for certain services. Please use /query to get a full list and older audits.
365 366 367 368 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 365 def post_audits_query_realtime(body, opts = {}) data, _status_code, _headers = post_audits_query_realtime_with_http_info(body, opts) return data end |
#post_audits_query_realtime_with_http_info(body, opts = {}) ⇒ Array<(AuditRealtimeQueryResultsResponse, Fixnum, Hash)>
This endpoint will only retrieve 7 days worth of audits for certain services. Please use /query to get a full list and older audits.
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 376 def post_audits_query_realtime_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditApi.post_audits_query_realtime ..." end # verify the required parameter 'body' is set fail ArgumentError, "Missing the required parameter 'body' when calling AuditApi.post_audits_query_realtime" if body.nil? # resource path local_var_path = "/api/v2/audits/query/realtime".sub('{format}','json') # query parameters query_params = {} query_params[:'expand'] = @api_client.build_collection_param(opts[:'expand'], :multi) if opts[:'expand'] # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(body) auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditRealtimeQueryResultsResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#post_audits_query_realtime\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_audits_query_with_http_info(body, opts = {}) ⇒ Array<(AuditQueryExecutionStatusResponse, Fixnum, Hash)>
Create audit query execution
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/purecloudplatformclientv2/api/audit_api.rb', line 309 def post_audits_query_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditApi.post_audits_query ..." end # verify the required parameter 'body' is set fail ArgumentError, "Missing the required parameter 'body' when calling AuditApi.post_audits_query" if body.nil? # resource path local_var_path = "/api/v2/audits/query".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(body) auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditQueryExecutionStatusResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditApi#post_audits_query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |