Class: PureCloud::OrganizationApi
- Inherits:
-
Object
- Object
- PureCloud::OrganizationApi
- Defined in:
- lib/purecloudplatformclientv2/api/organization_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_fieldconfig(type, opts = {}) ⇒ FieldConfig
Fetch field config for an entity type.
-
#get_fieldconfig_with_http_info(type, opts = {}) ⇒ Array<(FieldConfig, Fixnum, Hash)>
Fetch field config for an entity type.
-
#get_organizations_embeddedintegration(opts = {}) ⇒ EmbeddedIntegration
Get the list of domains that will be allowed to embed PureCloud applications.
-
#get_organizations_embeddedintegration_with_http_info(opts = {}) ⇒ Array<(EmbeddedIntegration, Fixnum, Hash)>
Get the list of domains that will be allowed to embed PureCloud applications.
-
#get_organizations_me(opts = {}) ⇒ Organization
Get organization.
-
#get_organizations_me_with_http_info(opts = {}) ⇒ Array<(Organization, Fixnum, Hash)>
Get organization.
-
#get_organizations_whitelist(opts = {}) ⇒ OrgWhitelistSettings
Use PUT /api/v2/organizations/embeddedintegration instead.
-
#get_organizations_whitelist_with_http_info(opts = {}) ⇒ Array<(OrgWhitelistSettings, Fixnum, Hash)>
Use PUT /api/v2/organizations/embeddedintegration instead.
-
#initialize(api_client = ApiClient.default) ⇒ OrganizationApi
constructor
A new instance of OrganizationApi.
-
#patch_organizations_feature(feature_name, enabled, opts = {}) ⇒ OrganizationFeatures
Update organization.
-
#patch_organizations_feature_with_http_info(feature_name, enabled, opts = {}) ⇒ Array<(OrganizationFeatures, Fixnum, Hash)>
Update organization.
-
#put_organizations_embeddedintegration(body, opts = {}) ⇒ EmbeddedIntegration
Update the list of domains that will be allowed to embed PureCloud applications.
-
#put_organizations_embeddedintegration_with_http_info(body, opts = {}) ⇒ Array<(EmbeddedIntegration, Fixnum, Hash)>
Update the list of domains that will be allowed to embed PureCloud applications.
-
#put_organizations_me(opts = {}) ⇒ Organization
Update organization.
-
#put_organizations_me_with_http_info(opts = {}) ⇒ Array<(Organization, Fixnum, Hash)>
Update organization.
-
#put_organizations_whitelist(body, opts = {}) ⇒ OrgWhitelistSettings
Use PUT /api/v2/organizations/embeddedintegration instead.
-
#put_organizations_whitelist_with_http_info(body, opts = {}) ⇒ Array<(OrgWhitelistSettings, Fixnum, Hash)>
Use PUT /api/v2/organizations/embeddedintegration instead.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OrganizationApi
Returns a new instance of OrganizationApi.
23 24 25 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 23 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
21 22 23 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 21 def api_client @api_client end |
Instance Method Details
#get_fieldconfig(type, opts = {}) ⇒ FieldConfig
Fetch field config for an entity type
32 33 34 35 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 32 def get_fieldconfig(type, opts = {}) data, _status_code, _headers = get_fieldconfig_with_http_info(type, opts) return data end |
#get_fieldconfig_with_http_info(type, opts = {}) ⇒ Array<(FieldConfig, Fixnum, Hash)>
Fetch field config for an entity type
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 42 def get_fieldconfig_with_http_info(type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.get_fieldconfig ..." end # verify the required parameter 'type' is set fail ArgumentError, "Missing the required parameter 'type' when calling OrganizationApi.get_fieldconfig" if type.nil? # verify enum value unless ['person', 'group', 'org', 'externalContact'].include?(type) fail ArgumentError, "invalid value for 'type', must be one of person, group, org, externalContact" end # resource path local_var_path = "/api/v2/fieldconfig".sub('{format}','json') # query parameters query_params = {} query_params[:'type'] = type # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'FieldConfig') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#get_fieldconfig\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_organizations_embeddedintegration(opts = {}) ⇒ EmbeddedIntegration
Get the list of domains that will be allowed to embed PureCloud applications
102 103 104 105 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 102 def (opts = {}) data, _status_code, _headers = (opts) return data end |
#get_organizations_embeddedintegration_with_http_info(opts = {}) ⇒ Array<(EmbeddedIntegration, Fixnum, Hash)>
Get the list of domains that will be allowed to embed PureCloud applications
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 111 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.get_organizations_embeddedintegration ..." end # resource path local_var_path = "/api/v2/organizations/embeddedintegration".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmbeddedIntegration') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#get_organizations_embeddedintegration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_organizations_me(opts = {}) ⇒ Organization
Get organization.
157 158 159 160 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 157 def get_organizations_me(opts = {}) data, _status_code, _headers = get_organizations_me_with_http_info(opts) return data end |
#get_organizations_me_with_http_info(opts = {}) ⇒ Array<(Organization, Fixnum, Hash)>
Get organization.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 166 def get_organizations_me_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.get_organizations_me ..." end # resource path local_var_path = "/api/v2/organizations/me".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Organization') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#get_organizations_me\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_organizations_whitelist(opts = {}) ⇒ OrgWhitelistSettings
Use PUT /api/v2/organizations/embeddedintegration instead
212 213 214 215 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 212 def get_organizations_whitelist(opts = {}) data, _status_code, _headers = get_organizations_whitelist_with_http_info(opts) return data end |
#get_organizations_whitelist_with_http_info(opts = {}) ⇒ Array<(OrgWhitelistSettings, Fixnum, Hash)>
Use PUT /api/v2/organizations/embeddedintegration instead
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 221 def get_organizations_whitelist_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.get_organizations_whitelist ..." end # resource path local_var_path = "/api/v2/organizations/whitelist".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrgWhitelistSettings') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#get_organizations_whitelist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_organizations_feature(feature_name, enabled, opts = {}) ⇒ OrganizationFeatures
Update organization
269 270 271 272 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 269 def patch_organizations_feature(feature_name, enabled, opts = {}) data, _status_code, _headers = patch_organizations_feature_with_http_info(feature_name, enabled, opts) return data end |
#patch_organizations_feature_with_http_info(feature_name, enabled, opts = {}) ⇒ Array<(OrganizationFeatures, Fixnum, Hash)>
Update organization
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 280 def patch_organizations_feature_with_http_info(feature_name, enabled, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.patch_organizations_feature ..." end # verify the required parameter 'feature_name' is set fail ArgumentError, "Missing the required parameter 'feature_name' when calling OrganizationApi.patch_organizations_feature" if feature_name.nil? # verify enum value unless ['realtimeCIC', 'purecloud', 'hipaa', 'ucEnabled', 'pci', 'purecloudVoice', 'xmppFederation', 'chat', 'informalPhotos', 'directory', 'contactCenter', 'unifiedCommunications', 'custserv'].include?(feature_name) fail ArgumentError, "invalid value for 'feature_name', must be one of realtimeCIC, purecloud, hipaa, ucEnabled, pci, purecloudVoice, xmppFederation, chat, informalPhotos, directory, contactCenter, unifiedCommunications, custserv" end # verify the required parameter 'enabled' is set fail ArgumentError, "Missing the required parameter 'enabled' when calling OrganizationApi.patch_organizations_feature" if enabled.nil? # resource path local_var_path = "/api/v2/organizations/features/{featureName}".sub('{format}','json').sub('{' + 'featureName' + '}', feature_name.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(enabled) auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationFeatures') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#patch_organizations_feature\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_organizations_embeddedintegration(body, opts = {}) ⇒ EmbeddedIntegration
Update the list of domains that will be allowed to embed PureCloud applications
348 349 350 351 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 348 def (body, opts = {}) data, _status_code, _headers = (body, opts) return data end |
#put_organizations_embeddedintegration_with_http_info(body, opts = {}) ⇒ Array<(EmbeddedIntegration, Fixnum, Hash)>
Update the list of domains that will be allowed to embed PureCloud applications
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 358 def (body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.put_organizations_embeddedintegration ..." end # verify the required parameter 'body' is set fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationApi.put_organizations_embeddedintegration" if body.nil? # resource path local_var_path = "/api/v2/organizations/embeddedintegration".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(body) auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmbeddedIntegration') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#put_organizations_embeddedintegration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_organizations_me(opts = {}) ⇒ Organization
Update organization.
413 414 415 416 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 413 def put_organizations_me(opts = {}) data, _status_code, _headers = put_organizations_me_with_http_info(opts) return data end |
#put_organizations_me_with_http_info(opts = {}) ⇒ Array<(Organization, Fixnum, Hash)>
Update organization.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 423 def put_organizations_me_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.put_organizations_me ..." end # resource path local_var_path = "/api/v2/organizations/me".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Organization') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#put_organizations_me\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_organizations_whitelist(body, opts = {}) ⇒ OrgWhitelistSettings
Use PUT /api/v2/organizations/embeddedintegration instead
476 477 478 479 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 476 def put_organizations_whitelist(body, opts = {}) data, _status_code, _headers = put_organizations_whitelist_with_http_info(body, opts) return data end |
#put_organizations_whitelist_with_http_info(body, opts = {}) ⇒ Array<(OrgWhitelistSettings, Fixnum, Hash)>
Use PUT /api/v2/organizations/embeddedintegration instead
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/purecloudplatformclientv2/api/organization_api.rb', line 486 def put_organizations_whitelist_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationApi.put_organizations_whitelist ..." end # verify the required parameter 'body' is set fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationApi.put_organizations_whitelist" if body.nil? # resource path local_var_path = "/api/v2/organizations/whitelist".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(body) auth_names = ['PureCloud OAuth'] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrgWhitelistSettings') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#put_organizations_whitelist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |